@@ -20,14 +20,13 @@ See https://en.wikipedia.org/wiki/Common_spatial_pattern and
 
 # %%
 
-
 import matplotlib.pyplot as plt
 import numpy as np
 from sklearn.discriminant_analysis import LinearDiscriminantAnalysis
 from sklearn.model_selection import ShuffleSplit, cross_val_score
 from sklearn.pipeline import Pipeline
 
-from mne import Epochs, events_from_annotations, pick_types
+from mne import Epochs, pick_types
 from mne.channels import make_standard_montage
 from mne.datasets import eegbci
 from mne.decoding import CSP
@@ -41,7 +40,6 @@ print(__doc__)
 # avoid classification of evoked responses by using epochs that start 1s after
 # cue onset.
 tmin, tmax = -1.0, 4.0
-event_id = dict(hands=2, feet=3)
 subject = 1
 runs = [6, 10, 14]  # motor imagery: hands vs feet
 
@@ -50,22 +48,21 @@ raw = concatenate_raws([read_raw_edf(f, preload=True) for f in raw_fnames])
 eegbci.standardize(raw)  # set channel names
 montage = make_standard_montage("standard_1005")
 raw.set_montage(montage)
+raw.annotations.rename(dict(T1="hands", T2="feet"))
+raw.set_eeg_reference(projection=True)
 
 # Apply band-pass filter
 raw.filter(7.0, 30.0, fir_design="firwin", skip_by_annotation="edge")
 
-events, _ = events_from_annotations(raw, event_id=dict(T1=2, T2=3))
-
 picks = pick_types(raw.info, meg=False, eeg=True, stim=False, eog=False, exclude="bads")
 
 # Read epochs (train will be done only between 1 and 2s)
 # Testing will be done with a running classifier
 epochs = Epochs(
     raw,
-    events,
-    event_id,
-    tmin,
-    tmax,
+    event_id=["hands", "feet"],
+    tmin=tmin,
+    tmax=tmax,
     proj=True,
     picks=picks,
     baseline=None,
@@ -95,9 +92,7 @@ scores = cross_val_score(clf, epochs_data_train, labels, cv=cv, n_jobs=None)
 # Printing the results
 class_balance = np.mean(labels == labels[0])
 class_balance = max(class_balance, 1.0 - class_balance)
-print(
-    "Classification accuracy: %f / Chance level: %f" % (np.mean(scores), class_balance)
-)
+print(f"Classification accuracy: {np.mean(scores)} / Chance level: {class_balance}")
 
 # plot CSP patterns estimated on full data for visualization
 csp.fit_transform(epochs_data, labels)
