@@ -23,11 +23,10 @@ try:
 
     __version__ = version("mne")
 except Exception:
-    try:
-        from ._version import __version__
-    except ImportError:
-        __version__ = "0.0.0"
+    __version__ = "0.0.0"
+
 (__getattr__, __dir__, __all__) = lazy.attach_stub(__name__, __file__)
+
 # initialize logging
 from .utils import set_log_level, set_log_file
 
