@@ -132,14 +132,15 @@ class DigPoint(dict):
             id_ = _cardinal_kind_rev.get(self["ident"], "Unknown cardinal")
         else:
             id_ = _dig_kind_proper[_dig_kind_rev.get(self["kind"], "unknown")]
-            id_ = "%s #%s" % (id_, self["ident"])
+            id_ = f"{id_} #{self['ident']}"
         id_ = id_.rjust(10)
         cf = _coord_frame_name(self["coord_frame"])
+        x, y, z = self["r"]
         if "voxel" in cf:
-            pos = ("(%0.1f, %0.1f, %0.1f)" % tuple(self["r"])).ljust(25)
+            pos = (f"({x:0.1f}, {y:0.1f}, {z:0.1f})").ljust(25)
         else:
-            pos = ("(%0.1f, %0.1f, %0.1f) mm" % tuple(1000 * self["r"])).ljust(25)
-        return "<DigPoint | %s : %s : %s frame>" % (id_, pos, cf)
+            pos = (f"({x * 1e3:0.1f}, {y * 1e3:0.1f}, {z * 1e3:0.1f}) mm").ljust(25)
+        return f"<DigPoint | {id_} : {pos} : {cf} frame>"
 
     # speed up info copy by only deep copying the mutable item
     def __deepcopy__(self, memodict):
@@ -362,8 +363,8 @@ def _coord_frame_const(coord_frame):
 
     if not isinstance(coord_frame, str) or coord_frame not in _str_to_frame:
         raise ValueError(
-            "coord_frame must be one of %s, got %s"
-            % (sorted(_str_to_frame.keys()), coord_frame)
+            f"coord_frame must be one of {sorted(_str_to_frame.keys())}, got "
+            f"{coord_frame}"
         )
     return _str_to_frame[coord_frame]
 
@@ -414,9 +415,7 @@ def _make_dig_points(
     if lpa is not None:
         lpa = np.asarray(lpa)
         if lpa.shape != (3,):
-            raise ValueError(
-                "LPA should have the shape (3,) instead of %s" % (lpa.shape,)
-            )
+            raise ValueError(f"LPA should have the shape (3,) instead of {lpa.shape}")
         dig.append(
             {
                 "r": lpa,
@@ -429,7 +428,7 @@ def _make_dig_points(
         nasion = np.asarray(nasion)
         if nasion.shape != (3,):
             raise ValueError(
-                "Nasion should have the shape (3,) instead of %s" % (nasion.shape,)
+                f"Nasion should have the shape (3,) instead of {nasion.shape}"
             )
         dig.append(
             {
@@ -442,9 +441,7 @@ def _make_dig_points(
     if rpa is not None:
         rpa = np.asarray(rpa)
         if rpa.shape != (3,):
-            raise ValueError(
-                "RPA should have the shape (3,) instead of %s" % (rpa.shape,)
-            )
+            raise ValueError(f"RPA should have the shape (3,) instead of {rpa.shape}")
         dig.append(
             {
                 "r": rpa,
@@ -457,8 +454,7 @@ def _make_dig_points(
         hpi = np.asarray(hpi)
         if hpi.ndim != 2 or hpi.shape[1] != 3:
             raise ValueError(
-                "HPI should have the shape (n_points, 3) instead "
-                "of %s" % (hpi.shape,)
+                f"HPI should have the shape (n_points, 3) instead of {hpi.shape}"
             )
         for idx, point in enumerate(hpi):
             dig.append(
@@ -473,8 +469,8 @@ def _make_dig_points(
         extra_points = np.asarray(extra_points)
         if len(extra_points) and extra_points.shape[1] != 3:
             raise ValueError(
-                "Points should have the shape (n_points, 3) "
-                "instead of %s" % (extra_points.shape,)
+                "Points should have the shape (n_points, 3) instead of "
+                f"{extra_points.shape}"
             )
         for idx, point in enumerate(extra_points):
             dig.append(
