@@ -38,6 +38,8 @@ from .utils import (
     _check_fname,
     _check_option,
     _check_pandas_installed,
+    _check_time_format,
+    _convert_times,
     _DefaultEventParser,
     _dt_to_stamp,
     _is_numeric,
@@ -63,15 +65,15 @@ def _check_o_d_s_c(onset, duration, description, ch_names):
     onset = np.atleast_1d(np.array(onset, dtype=float))
     if onset.ndim != 1:
         raise ValueError(
-            "Onset must be a one dimensional array, got %s "
-            "(shape %s)." % (onset.ndim, onset.shape)
+            f"Onset must be a one dimensional array, got {onset.ndim} (shape "
+            f"{onset.shape})."
         )
     duration = np.array(duration, dtype=float)
     if duration.ndim == 0 or duration.shape == (1,):
         duration = np.repeat(duration, len(onset))
     if duration.ndim != 1:
         raise ValueError(
-            "Duration must be a one dimensional array, " "got %d." % (duration.ndim,)
+            f"Duration must be a one dimensional array, got {duration.ndim}."
         )
 
     description = np.array(description, dtype=str)
@@ -79,8 +81,7 @@ def _check_o_d_s_c(onset, duration, description, ch_names):
         description = np.repeat(description, len(onset))
     if description.ndim != 1:
         raise ValueError(
-            "Description must be a one dimensional array, "
-            "got %d." % (description.ndim,)
+            f"Description must be a one dimensional array, got {description.ndim}."
         )
     _safe_name_list(description, "write", "description")
 
@@ -276,9 +277,7 @@ class Annotations:
     :meth:`Raw.save() <mne.io.Raw.save>` notes for details.
     """  # noqa: E501
 
-    def __init__(
-        self, onset, duration, description, orig_time=None, ch_names=None
-    ):  # noqa: D102
+    def __init__(self, onset, duration, description, orig_time=None, ch_names=None):
         self._orig_time = _handle_meas_date(orig_time)
         self.onset, self.duration, self.description, self.ch_names = _check_o_d_s_c(
             onset, duration, description, ch_names
@@ -305,14 +304,12 @@ class Annotations:
     def __repr__(self):
         """Show the representation."""
         counter = Counter(self.description)
-        kinds = ", ".join(["%s (%s)" % k for k in sorted(counter.items())])
+        kinds = ", ".join(["{} ({})".format(*k) for k in sorted(counter.items())])
         kinds = (": " if len(kinds) > 0 else "") + kinds
         ch_specific = ", channel-specific" if self._any_ch_names() else ""
-        s = "Annotations | %s segment%s%s%s" % (
-            len(self.onset),
-            _pl(len(self.onset)),
-            ch_specific,
-            kinds,
+        s = (
+            f"Annotations | {len(self.onset)} segment"
+            f"{_pl(len(self.onset))}{ch_specific}{kinds}"
         )
         return "<" + shorten(s, width=77, placeholder=" ...") + ">"
 
@@ -341,9 +338,8 @@ class Annotations:
             self._orig_time = other.orig_time
         if self.orig_time != other.orig_time:
             raise ValueError(
-                "orig_time should be the same to "
-                "add/concatenate 2 annotations "
-                "(got %s != %s)" % (self.orig_time, other.orig_time)
+                "orig_time should be the same to add/concatenate 2 annotations (got "
+                f"{self.orig_time} != {other.orig_time})"
             )
         return self.append(
             other.onset, other.duration, other.description, other.ch_names
@@ -444,9 +440,16 @@ class Annotations:
         self.description = np.delete(self.description, idx)
         self.ch_names = np.delete(self.ch_names, idx)
 
-    def to_data_frame(self):
+    @fill_doc
+    def to_data_frame(self, time_format="datetime"):
         """Export annotations in tabular structure as a pandas DataFrame.
 
+        Parameters
+        ----------
+        %(time_format_df_raw)s
+
+            .. versionadded:: 1.7
+
         Returns
         -------
         result : pandas.DataFrame
@@ -455,12 +458,14 @@ class Annotations:
             annotations are channel-specific.
         """
         pd = _check_pandas_installed(strict=True)
+        valid_time_formats = ["ms", "timedelta", "datetime"]
         dt = _handle_meas_date(self.orig_time)
         if dt is None:
             dt = _handle_meas_date(0)
+        time_format = _check_time_format(time_format, valid_time_formats, dt)
         dt = dt.replace(tzinfo=None)
-        onsets_dt = [dt + timedelta(seconds=o) for o in self.onset]
-        df = dict(onset=onsets_dt, duration=self.duration, description=self.description)
+        times = _convert_times(self.onset, time_format, dt)
+        df = dict(onset=times, duration=self.duration, description=self.description)
         if self._any_ch_names():
             df.update(ch_names=self.ch_names)
         df = pd.DataFrame(df)
@@ -612,10 +617,10 @@ class Annotations:
         del tmin, tmax
         if absolute_tmin > absolute_tmax:
             raise ValueError(
-                "tmax should be greater than or equal to tmin "
-                "(%s < %s)." % (absolute_tmin, absolute_tmax)
+                f"tmax should be greater than or equal to tmin ({absolute_tmin} < "
+                f"{absolute_tmax})."
             )
-        logger.debug("Cropping annotations %s - %s" % (absolute_tmin, absolute_tmax))
+        logger.debug(f"Cropping annotations {absolute_tmin} - {absolute_tmax}")
 
         onsets, durations, descriptions, ch_names = [], [], [], []
         out_of_bounds, clip_left_elem, clip_right_elem = [], [], []
@@ -813,11 +818,10 @@ class EpochAnnotationsMixin:
         else:
             if getattr(self, "_unsafe_annot_add", False):
                 warn(
-                    "Adding annotations to Epochs created (and saved to "
-                    "disk) before 1.0 will yield incorrect results if "
-                    "decimation or resampling was performed on the instance, "
-                    "we recommend regenerating the Epochs and re-saving them "
-                    "to disk."
+                    "Adding annotations to Epochs created (and saved to disk) before "
+                    "1.0 will yield incorrect results if decimation or resampling was "
+                    "performed on the instance, we recommend regenerating the Epochs "
+                    "and re-saving them to disk."
                 )
             new_annotations = annotations.copy()
             new_annotations._prune_ch_names(self.info, on_missing)
@@ -1141,7 +1145,9 @@ def _write_annotations_txt(fname, annot):
 
 
 @fill_doc
-def read_annotations(fname, sfreq="auto", uint16_codec=None, encoding="utf8"):
+def read_annotations(
+    fname, sfreq="auto", uint16_codec=None, encoding="utf8"
+) -> Annotations:
     r"""Read annotations from a file.
 
     This function reads a ``.fif``, ``.fif.gz``, ``.vmrk``, ``.amrk``,
@@ -1174,7 +1180,7 @@ def read_annotations(fname, sfreq="auto", uint16_codec=None, encoding="utf8"):
 
     Returns
     -------
-    annot : instance of Annotations | None
+    annot : instance of Annotations
         The annotations.
 
     Notes
@@ -1485,7 +1491,7 @@ def _check_event_id(event_id, raw):
     else:
         raise ValueError(
             "Invalid type for event_id (should be None, str, "
-            "dict or callable). Got {}".format(type(event_id))
+            f"dict or callable). Got {type(event_id)}."
         )
 
 
@@ -1500,16 +1506,14 @@ def _check_event_description(event_desc, events):
     elif isinstance(event_desc, Iterable):
         event_desc = np.asarray(event_desc)
         if event_desc.ndim != 1:
-            raise ValueError(
-                "event_desc must be 1D, got shape {}".format(event_desc.shape)
-            )
+            raise ValueError(f"event_desc must be 1D, got shape {event_desc.shape}")
         event_desc = dict(zip(event_desc, map(str, event_desc)))
     elif callable(event_desc):
         pass
     else:
         raise ValueError(
             "Invalid type for event_desc (should be None, list, "
-            "1darray, dict or callable). Got {}".format(type(event_desc))
+            f"1darray, dict or callable). Got {type(event_desc)}."
         )
 
     return event_desc
@@ -1522,6 +1526,7 @@ def events_from_annotations(
     regexp=r"^(?![Bb][Aa][Dd]|[Ee][Dd][Gg][Ee]).*$",
     use_rounding=True,
     chunk_duration=None,
+    tol=1e-8,
     verbose=None,
 ):
     """Get :term:`events` and ``event_id`` from an Annotations object.
@@ -1565,6 +1570,11 @@ def events_from_annotations(
         they fit within the annotation duration spaced according to
         ``chunk_duration``. As a consequence annotations with duration shorter
         than ``chunk_duration`` will not contribute events.
+    tol : float
+        The tolerance used to check if a chunk fits within an annotation when
+        ``chunk_duration`` is not ``None``. If the duration from a computed
+        chunk onset to the end of the annotation is smaller than
+        ``chunk_duration`` minus ``tol``, the onset will be discarded.
     %(verbose)s
 
     Returns
@@ -1609,10 +1619,8 @@ def events_from_annotations(
         inds = values = np.array([]).astype(int)
         for annot in annotations[event_sel]:
             annot_offset = annot["onset"] + annot["duration"]
-            _onsets = np.arange(
-                start=annot["onset"], stop=annot_offset, step=chunk_duration
-            )
-            good_events = annot_offset - _onsets >= chunk_duration
+            _onsets = np.arange(annot["onset"], annot_offset, chunk_duration)
+            good_events = annot_offset - _onsets >= chunk_duration - tol
             if good_events.any():
                 _onsets = _onsets[good_events]
                 _inds = raw.time_as_index(
@@ -1629,7 +1637,7 @@ def events_from_annotations(
 
     events = np.c_[inds, np.zeros(len(inds)), values].astype(int)
 
-    logger.info("Used Annotations descriptions: %s" % (list(event_id_.keys()),))
+    logger.info(f"Used Annotations descriptions: {list(event_id_.keys())}")
 
     return events, event_id_
 
