@@ -10,6 +10,7 @@ from numpy.testing import assert_allclose, assert_array_equal
 from mne import Epochs, pick_channels, pick_types, read_events
 from mne._fiff.constants import FIFF
 from mne._fiff.proj import _has_eeg_average_ref_proj
+from mne.channels import make_dig_montage
 from mne.channels.interpolation import _make_interpolation_matrix
 from mne.datasets import testing
 from mne.io import RawArray, read_raw_ctf, read_raw_fif, read_raw_nirx
@@ -20,7 +21,7 @@ from mne.preprocessing.nirs import (
 )
 from mne.utils import _record_warnings
 
-base_dir = Path(__file__).parent.parent.parent / "io" / "tests" / "data"
+base_dir = Path(__file__).parents[2] / "io" / "tests" / "data"
 raw_fname = base_dir / "test_raw.fif"
 event_name = base_dir / "test-eve.fif"
 raw_fname_ctf = base_dir / "test_ctf_raw.fif"
@@ -329,6 +330,55 @@ def test_interpolation_nirs():
     assert raw_haemo.info["bads"] == []
 
 
+@testing.requires_testing_data
+def test_interpolation_ecog():
+    """Test interpolation for ECoG."""
+    raw, epochs_eeg = _load_data("eeg")
+    bads = ["EEG 012"]
+    bads_mask = np.isin(epochs_eeg.ch_names, bads)
+
+    epochs_ecog = epochs_eeg.set_channel_types(
+        {ch: "ecog" for ch in epochs_eeg.ch_names}
+    )
+    epochs_ecog.info["bads"] = bads
+
+    # check that interpolation changes the data in raw
+    raw_ecog = RawArray(data=epochs_ecog._data[0], info=epochs_ecog.info)
+    raw_before = raw_ecog.copy()
+    raw_after = raw_ecog.interpolate_bads(method=dict(ecog="spline"))
+    assert not np.all(raw_before._data[bads_mask] == raw_after._data[bads_mask])
+    assert_array_equal(raw_before._data[~bads_mask], raw_after._data[~bads_mask])
+
+
+@testing.requires_testing_data
+def test_interpolation_seeg():
+    """Test interpolation for sEEG."""
+    raw, epochs_eeg = _load_data("eeg")
+    bads = ["EEG 012"]
+    bads_mask = np.isin(epochs_eeg.ch_names, bads)
+    epochs_seeg = epochs_eeg.set_channel_types(
+        {ch: "seeg" for ch in epochs_eeg.ch_names}
+    )
+    epochs_seeg.info["bads"] = bads
+
+    # check that interpolation changes the data in raw
+    raw_seeg = RawArray(data=epochs_seeg._data[0], info=epochs_seeg.info)
+    raw_before = raw_seeg.copy()
+    with pytest.raises(RuntimeError, match="1 good contact"):
+        raw_seeg.interpolate_bads(method=dict(seeg="spline"))
+    montage = raw_seeg.get_montage()
+    pos = montage.get_positions()
+    ch_pos = pos.pop("ch_pos")
+    n0 = ch_pos[epochs_seeg.ch_names[0]]
+    n1 = ch_pos[epochs_seeg.ch_names[1]]
+    for i, ch in enumerate(epochs_seeg.ch_names[2:]):
+        ch_pos[ch] = n0 + (n1 - n0) * (i + 2)
+    raw_seeg.set_montage(make_dig_montage(ch_pos, **pos))
+    raw_after = raw_seeg.interpolate_bads(method=dict(seeg="spline"))
+    assert not np.all(raw_before._data[bads_mask] == raw_after._data[bads_mask])
+    assert_array_equal(raw_before._data[~bads_mask], raw_after._data[~bads_mask])
+
+
 def test_nan_interpolation(raw):
     """Test 'nan' method for interpolating bads."""
     ch_to_interp = [raw.ch_names[1]]  # don't use channel 0 (type is IAS not MEG)
