@@ -256,7 +256,7 @@ def run():
             raise ValueError('qrsthr must be "auto" or a float')
 
     if bad_fname is not None:
-        with open(bad_fname, "r") as fid:
+        with open(bad_fname) as fid:
             bads = [w.rstrip() for w in fid.readlines()]
         print("Bad channels read : %s" % bads)
     else:
