@@ -41,25 +41,6 @@ def run():
         default=None,
         help="FIFF file with digitizer data for coregistration",
     )
-    parser.add_option(
-        "-t",
-        "--tabbed",
-        dest="tabbed",
-        action="store_true",
-        default=None,
-        help="Option for small screens: Combine "
-        "the data source panel and the coregistration panel "
-        "into a single panel with tabs.",
-    )
-    parser.add_option(
-        "--no-guess-mri",
-        dest="guess_mri_subject",
-        action="store_false",
-        default=None,
-        help="Prevent the GUI from automatically guessing and "
-        "changing the MRI subject when a new head shape source "
-        "file is selected.",
-    )
     parser.add_option(
         "--head-opacity",
         type=float,
@@ -94,20 +75,6 @@ def run():
         dest="interaction",
         help='Interaction style to use, can be "trackball" or ' '"terrain".',
     )
-    parser.add_option(
-        "--scale",
-        type=float,
-        default=None,
-        dest="scale",
-        help="Scale factor for the scene.",
-    )
-    parser.add_option(
-        "--simple-rendering",
-        action="store_false",
-        dest="advanced_rendering",
-        default=None,
-        help="Use simplified OpenGL rendering",
-    )
     _add_verbose_flag(parser)
 
     options, args = parser.parse_args()
@@ -134,18 +101,13 @@ def run():
 
     faulthandler.enable()
     mne.gui.coregistration(
-        tabbed=options.tabbed,
         inst=options.inst,
         subject=options.subject,
         subjects_dir=subjects_dir,
-        guess_mri_subject=options.guess_mri_subject,
         head_opacity=options.head_opacity,
         head_high_res=head_high_res,
         trans=trans,
-        scrollable=None,
         interaction=options.interaction,
-        scale=options.scale,
-        advanced_rendering=options.advanced_rendering,
         show=True,
         block=True,
         verbose=options.verbose,
