@@ -4,21 +4,26 @@
 #          Stefan Appelhoff <stefan.appelhoff@mailbox.org>
 #
 # License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 import glob
 import importlib
 import os
 import os.path as op
-from optparse import OptionParser
 import sys
+from optparse import OptionParser
 
 import mne
 
 
 def _add_verbose_flag(parser):
-    parser.add_option("--verbose", dest='verbose',
-                      help="Enable verbose mode (printing of log messages).",
-                      default=None, action="store_true")
+    parser.add_option(
+        "--verbose",
+        dest="verbose",
+        help="Enable verbose mode (printing of log messages).",
+        default=None,
+        action="store_true",
+    )
 
 
 def load_module(name, path):
@@ -37,32 +42,33 @@ def load_module(name, path):
         Imported module.
 
     """
-    from importlib.util import spec_from_file_location, module_from_spec
+    from importlib.util import module_from_spec, spec_from_file_location
+
     spec = spec_from_file_location(name, path)
     mod = module_from_spec(spec)
     spec.loader.exec_module(mod)
     return mod
 
 
-def get_optparser(cmdpath, usage=None, prog_prefix='mne', version=None):
+def get_optparser(cmdpath, usage=None, prog_prefix="mne", version=None):
     """Create OptionParser with cmd specific settings (e.g., prog value)."""
     # Fetch description
-    mod = load_module('__temp', cmdpath)
+    mod = load_module("__temp", cmdpath)
     if mod.__doc__:
         doc, description, epilog = mod.__doc__, None, None
 
-        doc_lines = doc.split('\n')
+        doc_lines = doc.split("\n")
         description = doc_lines[0]
         if len(doc_lines) > 1:
-            epilog = '\n'.join(doc_lines[1:])
+            epilog = "\n".join(doc_lines[1:])
 
     # Get the name of the command
     command = os.path.basename(cmdpath)
     command, _ = os.path.splitext(command)
-    command = command[len(prog_prefix) + 1:]  # +1 is for `_` character
+    command = command[len(prog_prefix) + 1 :]  # +1 is for `_` character
 
     # Set prog
-    prog = prog_prefix + ' {}'.format(command)
+    prog = prog_prefix + f" {command}"
 
     # Set version
     if version is None:
@@ -70,10 +76,9 @@ def get_optparser(cmdpath, usage=None, prog_prefix='mne', version=None):
 
     # monkey patch OptionParser to not wrap epilog
     OptionParser.format_epilog = lambda self, formatter: self.epilog
-    parser = OptionParser(prog=prog,
-                          version=version,
-                          description=description,
-                          epilog=epilog, usage=usage)
+    parser = OptionParser(
+        prog=prog, version=version, description=description, epilog=epilog, usage=usage
+    )
 
     return parser
 
@@ -81,8 +86,7 @@ def get_optparser(cmdpath, usage=None, prog_prefix='mne', version=None):
 def main():
     """Entrypoint for mne <command> usage."""
     mne_bin_dir = op.dirname(op.dirname(__file__))
-    valid_commands = sorted(glob.glob(op.join(mne_bin_dir,
-                                              'commands', 'mne_*.py')))
+    valid_commands = sorted(glob.glob(op.join(mne_bin_dir, "commands", "mne_*.py")))
     valid_commands = [c.split(op.sep)[-1][4:-3] for c in valid_commands]
 
     def print_help():  # noqa
@@ -102,6 +106,6 @@ def main():
         print_help()
     else:
         cmd = sys.argv[1]
-        cmd = importlib.import_module('.mne_%s' % (cmd,), 'mne.commands')
+        cmd = importlib.import_module(f".mne_{cmd}", "mne.commands")
         sys.argv = sys.argv[1:]
         cmd.run()
