@@ -59,7 +59,7 @@ from .fixes import (
     empirical_covariance,
     log_likelihood,
 )
-from .rank import compute_rank
+from .rank import _compute_rank
 from .utils import (
     _array_repr,
     _check_fname,
@@ -85,12 +85,12 @@ from .utils import (
 
 def _check_covs_algebra(cov1, cov2):
     if cov1.ch_names != cov2.ch_names:
-        raise ValueError("Both Covariance do not have the same list of " "channels.")
+        raise ValueError("Both Covariance do not have the same list of channels.")
     projs1 = [str(c) for c in cov1["projs"]]
     projs2 = [str(c) for c in cov1["projs"]]
     if projs1 != projs2:
         raise ValueError(
-            "Both Covariance do not have the same list of " "SSP projections."
+            "Both Covariance do not have the same list of SSP projections."
         )
 
 
@@ -310,7 +310,7 @@ class Covariance(dict):
     def plot(
         self,
         info,
-        exclude=[],
+        exclude=(),
         colorbar=True,
         proj=False,
         show_svd=True,
@@ -453,7 +453,7 @@ class Covariance(dict):
         )
 
     @verbose
-    def pick_channels(self, ch_names, ordered=None, *, verbose=None):
+    def pick_channels(self, ch_names, ordered=True, *, verbose=None):
         """Pick channels from this covariance matrix.
 
         Parameters
@@ -704,7 +704,7 @@ def compute_raw_covariance(
     tstep = tmax - tmin if tstep is None else float(tstep)
     tstep_m1 = tstep - dt  # inclusive!
     events = make_fixed_length_events(raw, 1, tmin, tmax, tstep)
-    logger.info("Using up to %s segment%s" % (len(events), _pl(events)))
+    logger.info(f"Using up to {len(events)} segment{_pl(events)}")
 
     # don't exclude any bad channels, inverses expect all channels present
     if picks is None:
@@ -819,13 +819,13 @@ def _check_method_params(
         for key, values in method_params.items():
             if key not in _method_params:
                 raise ValueError(
-                    'key (%s) must be "%s"' % (key, '" or "'.join(_method_params))
+                    'key ({}) must be "{}"'.format(key, '" or "'.join(_method_params))
                 )
 
             _method_params[key].update(method_params[key])
         shrinkage = method_params.get("shrinkage", {}).get("shrinkage", 0.1)
         if not 0 <= shrinkage <= 1:
-            raise ValueError("shrinkage must be between 0 and 1, got %s" % (shrinkage,))
+            raise ValueError(f"shrinkage must be between 0 and 1, got {shrinkage}")
 
     was_auto = False
     if method is None:
@@ -839,10 +839,8 @@ def _check_method_params(
 
     if not all(k in accepted_methods for k in method):
         raise ValueError(
-            "Invalid {name} ({method}). Accepted values (individually or "
-            'in a list) are any of "{accepted_methods}" or None.'.format(
-                name=name, method=method, accepted_methods=accepted_methods
-            )
+            f"Invalid {name} ({method}). Accepted values (individually or "
+            f"in a list) are any of '{accepted_methods}' or None."
         )
     if not (isinstance(rank, str) and rank == "full"):
         if was_auto:
@@ -850,19 +848,18 @@ def _check_method_params(
         for method_ in method:
             if method_ in ("pca", "factor_analysis"):
                 raise ValueError(
-                    '%s can so far only be used with rank="full",'
-                    " got rank=%r" % (method_, rank)
+                    f'{method_} can so far only be used with rank="full", got rank='
+                    f"{rank!r}"
                 )
     if not keep_sample_mean:
         if len(method) != 1 or "empirical" not in method:
             raise ValueError(
-                "`keep_sample_mean=False` is only supported"
-                'with %s="empirical"' % (name,)
+                f'`keep_sample_mean=False` is only supported with {name}="empirical"'
             )
         for p, v in _method_params.items():
             if v.get("assume_centered", None) is False:
                 raise ValueError(
-                    "`assume_centered` must be True" " if `keep_sample_mean` is False"
+                    "`assume_centered` must be True if `keep_sample_mean` is False"
                 )
     return method, _method_params
 
@@ -1077,9 +1074,7 @@ def compute_covariance(
         and keep_sample_mean
         for epochs_t in epochs
     ):
-        warn(
-            "Epochs are not baseline corrected, covariance " "matrix may be inaccurate"
-        )
+        warn("Epochs are not baseline corrected, covariance matrix may be inaccurate")
 
     orig = epochs[0].info["dev_head_t"]
     _check_on_missing(on_mismatch, "on_mismatch")
@@ -1090,8 +1085,8 @@ def compute_covariance(
             and not np.allclose(orig["trans"], epoch.info["dev_head_t"]["trans"])
         ):
             msg = (
-                "MEG<->Head transform mismatch between epochs[0]:\n%s\n\n"
-                "and epochs[%s]:\n%s" % (orig, ei, epoch.info["dev_head_t"])
+                "MEG<->Head transform mismatch between epochs[0]:\n{}\n\n"
+                "and epochs[{}]:\n{}".format(orig, ei, epoch.info["dev_head_t"])
             )
             _on_missing(on_mismatch, msg, "on_mismatch")
 
@@ -1196,7 +1191,7 @@ def compute_covariance(
     if len(covs) > 1:
         msg = ["log-likelihood on unseen data (descending order):"]
         for c in covs:
-            msg.append("%s: %0.3f" % (c["method"], c["loglik"]))
+            msg.append(f"{c['method']}: {c['loglik']:0.3f}")
         logger.info("\n   ".join(msg))
         if return_estimators:
             out = covs
@@ -1216,7 +1211,7 @@ def _check_scalings_user(scalings):
             _check_option("the keys in `scalings`", k, ["mag", "grad", "eeg"])
     elif scalings is not None and not isinstance(scalings, np.ndarray):
         raise TypeError(
-            "scalings must be a dict, ndarray, or None, got %s" % type(scalings)
+            f"scalings must be a dict, ndarray, or None, got {type(scalings)}"
         )
     scalings = _handle_default("scalings", scalings)
     return scalings
@@ -1231,6 +1226,21 @@ def _eigvec_subspace(eig, eigvec, mask):
     return eig, eigvec
 
 
+@verbose
+def _compute_rank_raw_array(
+    data, info, rank, scalings, *, log_ch_type=None, verbose=None
+):
+    from .io import RawArray
+
+    return _compute_rank(
+        RawArray(data, info, copy=None, verbose=_verbose_safe_false()),
+        rank,
+        scalings,
+        info,
+        log_ch_type=log_ch_type,
+    )
+
+
 def _compute_covariance_auto(
     data,
     method,
@@ -1242,22 +1252,31 @@ def _compute_covariance_auto(
     stop_early,
     picks_list,
     rank,
+    *,
+    cov_kind="",
+    log_ch_type=None,
+    log_rank=True,
 ):
     """Compute covariance auto mode."""
-    from .io import RawArray
-
     # rescale to improve numerical stability
     orig_rank = rank
-    rank = compute_rank(
-        RawArray(data.T, info, copy=None, verbose=_verbose_safe_false()),
-        rank,
-        scalings,
+    rank = _compute_rank_raw_array(
+        data.T,
         info,
+        rank=rank,
+        scalings=scalings,
+        verbose=_verbose_safe_false(),
     )
     with _scaled_array(data.T, picks_list, scalings):
         C = np.dot(data.T, data)
         _, eigvec, mask = _smart_eigh(
-            C, info, rank, proj_subspace=True, do_compute_rank=False
+            C,
+            info,
+            rank,
+            proj_subspace=True,
+            do_compute_rank=False,
+            log_ch_type=log_ch_type,
+            verbose=None if log_rank else _verbose_safe_false(),
         )
         eigvec = eigvec[mask]
         data = np.dot(data, eigvec.T)
@@ -1266,21 +1285,24 @@ def _compute_covariance_auto(
             (key, np.searchsorted(used, picks)) for key, picks in picks_list
         ]
         sub_info = pick_info(info, used) if len(used) != len(mask) else info
-        logger.info("Reducing data rank from %s -> %s" % (len(mask), eigvec.shape[0]))
+        if log_rank:
+            logger.info(f"Reducing data rank from {len(mask)} -> {eigvec.shape[0]}")
         estimator_cov_info = list()
-        msg = "Estimating covariance using %s"
 
         ok_sklearn = check_version("sklearn")
         if not ok_sklearn and (len(method) != 1 or method[0] != "empirical"):
             raise ValueError(
-                "scikit-learn is not installed, `method` must be "
-                "`empirical`, got %s" % (method,)
+                'scikit-learn is not installed, `method` must be "empirical", got '
+                f"{repr(method)}"
             )
 
         for method_ in method:
             data_ = data.copy()
             name = method_.__name__ if callable(method_) else method_
-            logger.info(msg % name.upper())
+            logger.info(
+                f'Estimating {cov_kind + (" " if cov_kind else "")}'
+                f"covariance using {name.upper()}"
+            )
             mp = method_params[method_]
             _info = {}
 
@@ -1375,7 +1397,7 @@ def _compute_covariance_auto(
                 estimator_cov_info.append((fa, fa.get_covariance(), _info))
                 del fa
             else:
-                raise ValueError("Oh no! Your estimator does not have" " a .fit method")
+                raise ValueError("Oh no! Your estimator does not have a .fit method")
             logger.info("Done.")
 
         if len(method) > 1:
@@ -1696,8 +1718,8 @@ def _get_ch_whitener(A, pca, ch_type, rank):
     mask[:-rank] = False
 
     logger.info(
-        "    Setting small %s eigenvalues to zero (%s)"
-        % (ch_type, "using PCA" if pca else "without PCA")
+        f"    Setting small {ch_type} eigenvalues to zero "
+        f'({"using" if pca else "without"} PCA)'
     )
     if pca:  # No PCA case.
         # This line will reduce the actual number of variables in data
@@ -1795,6 +1817,8 @@ def _smart_eigh(
     proj_subspace=False,
     do_compute_rank=True,
     on_rank_mismatch="ignore",
+    *,
+    log_ch_type=None,
     verbose=None,
 ):
     """Compute eigh of C taking into account rank and ch_type scalings."""
@@ -1817,8 +1841,13 @@ def _smart_eigh(
 
     noise_cov = Covariance(C, ch_names, [], projs, 0)
     if do_compute_rank:  # if necessary
-        rank = compute_rank(
-            noise_cov, rank, scalings, info, on_rank_mismatch=on_rank_mismatch
+        rank = _compute_rank(
+            noise_cov,
+            rank,
+            scalings,
+            info,
+            on_rank_mismatch=on_rank_mismatch,
+            log_ch_type=log_ch_type,
         )
     assert C.ndim == 2 and C.shape[0] == C.shape[1]
 
@@ -1842,7 +1871,11 @@ def _smart_eigh(
         else:
             this_rank = rank[ch_type]
 
-        e, ev, m = _get_ch_whitener(this_C, False, ch_type.upper(), this_rank)
+        if log_ch_type is not None:
+            ch_type_ = log_ch_type
+        else:
+            ch_type_ = ch_type.upper()
+        e, ev, m = _get_ch_whitener(this_C, False, ch_type_, this_rank)
         if proj_subspace:
             # Choose the subspace the same way we do for projections
             e, ev = _eigvec_subspace(e, ev, m)
@@ -1991,16 +2024,15 @@ def regularize(
     if len(picks_dict.get("meg", [])) > 0 and rank != "full":  # combined
         if mag != grad:
             raise ValueError(
-                "On data where magnetometers and gradiometers "
-                "are dependent (e.g., SSSed data), mag (%s) must "
-                "equal grad (%s)" % (mag, grad)
+                "On data where magnetometers and gradiometers are dependent (e.g., "
+                f"SSSed data), mag ({mag}) must equal grad ({grad})"
             )
         logger.info("Regularizing MEG channels jointly")
         regs["meg"] = mag
     else:
         regs.update(mag=mag, grad=grad)
     if rank != "full":
-        rank = compute_rank(cov, rank, scalings, info)
+        rank = _compute_rank(cov, rank, scalings, info)
 
     info_ch_names = info["ch_names"]
     ch_names_by_type = dict()
@@ -2039,9 +2071,9 @@ def regularize(
             continue
         reg = regs[ch_type]
         if reg == 0.0:
-            logger.info("    %s regularization : None" % desc)
+            logger.info(f"    {desc} regularization : None")
             continue
-        logger.info("    %s regularization : %s" % (desc, reg))
+        logger.info(f"    {desc} regularization : {reg}")
 
         this_C = C[np.ix_(idx, idx)]
         U = np.eye(this_C.shape[0])
@@ -2053,8 +2085,7 @@ def regularize(
                     # This adjustment ends up being redundant if rank is None:
                     U = _safe_svd(P)[0][:, :-ncomp]
                     logger.info(
-                        "    Created an SSP operator for %s "
-                        "(dimension = %d)" % (desc, ncomp)
+                        f"    Created an SSP operator for {desc} (dimension = {ncomp})"
                     )
         else:
             this_picks = pick_channels(info["ch_names"], this_ch_names)
@@ -2077,7 +2108,17 @@ def regularize(
     return cov
 
 
-def _regularized_covariance(data, reg=None, method_params=None, info=None, rank=None):
+def _regularized_covariance(
+    data,
+    reg=None,
+    method_params=None,
+    info=None,
+    rank=None,
+    *,
+    log_ch_type=None,
+    log_rank=None,
+    cov_kind="",
+):
     """Compute a regularized covariance from data using sklearn.
 
     This is a convenience wrapper for mne.decoding functions, which
@@ -2095,8 +2136,8 @@ def _regularized_covariance(data, reg=None, method_params=None, info=None, rank=
         reg = float(reg)
         if method_params is not None:
             raise ValueError(
-                "If reg is a float, method_params must be None "
-                "(got %s)" % (type(method_params),)
+                "If reg is a float, method_params must be None (got "
+                f"{type(method_params)})"
             )
         method_params = dict(
             shrinkage=dict(shrinkage=reg, assume_centered=True, store_precision=False)
@@ -2120,6 +2161,9 @@ def _regularized_covariance(data, reg=None, method_params=None, info=None, rank=
         picks_list=picks_list,
         scalings=scalings,
         rank=rank,
+        cov_kind=cov_kind,
+        log_ch_type=log_ch_type,
+        log_rank=log_rank,
     )[reg]["data"]
     return cov
 
@@ -2190,12 +2234,12 @@ def compute_whitener(
     _validate_type(pca, (str, bool), "space")
     _valid_pcas = (True, "white", False)
     if pca not in _valid_pcas:
-        raise ValueError("space must be one of %s, got %s" % (_valid_pcas, pca))
+        raise ValueError(f"space must be one of {_valid_pcas}, got {pca}")
     if info is None:
         if "eig" not in noise_cov:
             raise ValueError(
-                "info can only be None if the noise cov has "
-                "already been prepared with prepare_noise_cov"
+                "info can only be None if the noise cov has already been prepared with "
+                "prepare_noise_cov"
             )
         ch_names = deepcopy(noise_cov["names"])
     else:
@@ -2342,7 +2386,7 @@ def _read_cov(fid, node, cov_kind, limited=False, verbose=None):
                 names = _safe_name_list(tag.data, "read", "names")
                 if len(names) != dim:
                     raise ValueError(
-                        "Number of names does not match " "covariance matrix dimension"
+                        "Number of names does not match covariance matrix dimension"
                     )
 
             tag = find_tag(fid, this, FIFF.FIFF_MNE_COV)
@@ -2488,7 +2532,7 @@ def _write_cov(fid, cov):
 @verbose
 def _ensure_cov(cov, name="cov", *, verbose=None):
     _validate_type(cov, ("path-like", Covariance), name)
-    logger.info("Noise covariance  : %s" % (cov,))
+    logger.info(f"Noise covariance  : {cov}")
     if not isinstance(cov, Covariance):
         cov = read_cov(cov, verbose=_verbose_safe_false())
     return cov
