@@ -30,8 +30,8 @@ def _keep_basename_only(paths):
 
 def _get_expected_url(name):
     base = "https://physionet.org/physiobank/database/sleep-edfx/"
-    midle = "sleep-cassette/" if name.startswith("SC") else "sleep-telemetry/"
-    return base + midle + "/" + name
+    middle = "sleep-cassette/" if name.startswith("SC") else "sleep-telemetry/"
+    return base + middle + "/" + name
 
 
 def _get_expected_path(base, name):
@@ -46,12 +46,12 @@ def _check_mocked_function_calls(mocked_func, call_fname_hash_pairs, base_path):
     # order.
     for idx, current in enumerate(call_fname_hash_pairs):
         _, call_kwargs = mocked_func.call_args_list[idx]
-        hash_type, hash = call_kwargs["known_hash"].split(":")
+        hash_type, hash_ = call_kwargs["known_hash"].split(":")
         assert call_kwargs["url"] == _get_expected_url(current["name"]), idx
         assert Path(call_kwargs["path"], call_kwargs["fname"]) == _get_expected_path(
             base_path, current["name"]
         )
-        assert hash == current["hash"]
+        assert hash_ == current["hash"]
         assert hash_type == "sha1"
 
 
