@@ -5,6 +5,7 @@
 import logging
 
 import numpy as np
+from scipy.sparse import issparse
 
 from ..fixes import _get_check_scoring
 from ..parallel import parallel_func
@@ -46,7 +47,7 @@ class SlidingEstimator(BaseEstimator, TransformerMixin):
         position=0,
         allow_2d=False,
         verbose=None,
-    ):  # noqa: D102
+    ):
         _check_estimator(base_estimator)
         self.base_estimator = base_estimator
         self.n_jobs = n_jobs
@@ -63,7 +64,7 @@ class SlidingEstimator(BaseEstimator, TransformerMixin):
         return getattr(self.base_estimator, "_estimator_type", None)
 
     def __repr__(self):  # noqa: D105
-        repr_str = "<" + super(SlidingEstimator, self).__repr__()
+        repr_str = "<" + super().__repr__()
         if hasattr(self, "estimators_"):
             repr_str = repr_str[:-1]
             repr_str += ", fitted with %i estimators" % len(self.estimators_)
@@ -254,6 +255,12 @@ class SlidingEstimator(BaseEstimator, TransformerMixin):
 
     def _check_Xy(self, X, y=None):
         """Aux. function to check input data."""
+        # Once we require sklearn 1.1+ we should do something like:
+        # from sklearn.utils import check_array
+        # X = check_array(X, ensure_2d=False, input_name="X")
+        # y = check_array(y, dtype=None, ensure_2d=False, input_name="y")
+        if issparse(X):
+            raise TypeError("X should be a dense array, got sparse instead.")
         X = np.asarray(X)
         if y is not None:
             y = np.asarray(y)
@@ -320,9 +327,8 @@ class SlidingEstimator(BaseEstimator, TransformerMixin):
     def classes_(self):
         if not hasattr(self.estimators_[0], "classes_"):
             raise AttributeError(
-                "classes_ attribute available only if "
-                "base_estimator has it, and estimator %s does"
-                " not" % (self.estimators_[0],)
+                "classes_ attribute available only if base_estimator has it, and "
+                f"estimator {self.estimators_[0]} does not"
             )
         return self.estimators_[0].classes_
 
@@ -466,7 +472,7 @@ class GeneralizingEstimator(SlidingEstimator):
     """
 
     def __repr__(self):  # noqa: D105
-        repr_str = super(GeneralizingEstimator, self).__repr__()
+        repr_str = super().__repr__()
         if hasattr(self, "estimators_"):
             repr_str = repr_str[:-1]
             repr_str += ", fitted with %i estimators>" % len(self.estimators_)
