@@ -19,7 +19,7 @@ freqs_noise = 8, 13
 
 
 def simulate_data(
-    freqs_sig=[9, 12],
+    freqs_sig=(9, 12),
     n_trials=100,
     n_channels=20,
     n_samples=500,
