@@ -107,9 +107,7 @@ class Scaler(TransformerMixin, BaseEstimator):
         if ``scalings`` is a dict or None).
     """
 
-    def __init__(
-        self, info=None, scalings=None, with_mean=True, with_std=True
-    ):  # noqa: D102
+    def __init__(self, info=None, scalings=None, with_mean=True, with_std=True):
         self.info = info
         self.with_mean = with_mean
         self.with_std = with_std
@@ -333,7 +331,7 @@ class Vectorizer(TransformerMixin):
         X = np.asarray(X)
         if X.ndim not in (2, 3):
             raise ValueError(
-                "X should be of 2 or 3 dimensions but has shape " "%s" % (X.shape,)
+                "X should be of 2 or 3 dimensions but has shape " f"{X.shape}"
             )
         return X.reshape(X.shape[:-1] + self.features_shape_)
 
@@ -384,7 +382,7 @@ class PSDEstimator(TransformerMixin):
         normalization="length",
         *,
         verbose=None,
-    ):  # noqa: D102
+    ):
         self.sfreq = sfreq
         self.fmin = fmin
         self.fmax = fmax
@@ -492,10 +490,9 @@ class FilterEstimator(TransformerMixin):
 
     Notes
     -----
-    This is primarily meant for use in conjunction with
-    :class:`mne_realtime.RtEpochs`. In general it is not recommended in a
-    normal processing pipeline as it may result in edge artifacts. Use with
-    caution.
+    This is primarily meant for use in realtime applications.
+    In general it is not recommended in a normal processing pipeline as it may result
+    in edge artifacts. Use with caution.
     """
 
     def __init__(
@@ -513,7 +510,7 @@ class FilterEstimator(TransformerMixin):
         fir_design="firwin",
         *,
         verbose=None,
-    ):  # noqa: D102
+    ):
         self.info = info
         self.l_freq = l_freq
         self.h_freq = h_freq
@@ -626,7 +623,7 @@ class UnsupervisedSpatialFilter(TransformerMixin, BaseEstimator):
         (e.g. epochs).
     """
 
-    def __init__(self, estimator, average=False):  # noqa: D102
+    def __init__(self, estimator, average=False):
         # XXX: Use _check_estimator #3381
         for attr in ("fit", "transform", "fit_transform"):
             if not hasattr(estimator, attr):
@@ -839,7 +836,7 @@ class TemporalFilter(TransformerMixin):
         fir_design="firwin",
         *,
         verbose=None,
-    ):  # noqa: D102
+    ):
         self.l_freq = l_freq
         self.h_freq = h_freq
         self.sfreq = sfreq
