@@ -69,12 +69,12 @@ def _get_legen_table(
         # Updated due to API change (GH 1167)
         os.makedirs(fname)
     if ch_type == "meg":
-        fname = op.join(fname, "legder_%s_%s.bin" % (n_coeff, n_interp))
+        fname = op.join(fname, f"legder_{n_coeff}_{n_interp}.bin")
         leg_fun = _get_legen_der
         extra_str = " derivative"
         lut_shape = (n_interp + 1, n_coeff, 3)
     else:  # 'eeg'
-        fname = op.join(fname, "legval_%s_%s.bin" % (n_coeff, n_interp))
+        fname = op.join(fname, f"legval_{n_coeff}_{n_interp}.bin")
         leg_fun = _get_legen
         extra_str = ""
         lut_shape = (n_interp + 1, n_coeff)
