@@ -237,10 +237,16 @@ def test_make_field_map_meeg():
         assert_allclose(map_["data"].min(), min_, rtol=5e-2)
     # calculated from correct looking mapping on 2015/12/26
     assert_allclose(
-        np.sqrt(np.sum(maps[0]["data"] ** 2)), 19.0903, atol=1e-3, rtol=1e-3  # 16.6088,
+        np.sqrt(np.sum(maps[0]["data"] ** 2)),
+        19.0903,
+        atol=1e-3,
+        rtol=1e-3,
     )
     assert_allclose(
-        np.sqrt(np.sum(maps[1]["data"] ** 2)), 19.4748, atol=1e-3, rtol=1e-3  # 20.1245,
+        np.sqrt(np.sum(maps[1]["data"] ** 2)),
+        19.4748,
+        atol=1e-3,
+        rtol=1e-3,
     )
 
 
