@@ -243,7 +243,7 @@ def _mixed_norm_solver_bcd(
             )
 
             if gap < tol:
-                logger.debug("Convergence reached ! (gap: %s < %s)" % (gap, tol))
+                logger.debug(f"Convergence reached ! (gap: {gap} < {tol})")
                 break
 
         # using Anderson acceleration of the primal variable for faster
@@ -525,7 +525,7 @@ def mixed_norm_solver(
                 )
             )
             if gap < tol:
-                logger.info("Convergence reached ! (gap: %s < %s)" % (gap, tol))
+                logger.info(f"Convergence reached ! (gap: {gap} < {tol})")
                 break
 
             # add sources if not last iteration
@@ -545,7 +545,7 @@ def mixed_norm_solver(
                 idx = np.searchsorted(idx_active_set, idx_old_active_set)
                 X_init[idx] = X
         else:
-            warn("Did NOT converge ! (gap: %s > %s)" % (gap, tol))
+            warn(f"Did NOT converge ! (gap: {gap} > {tol})")
     else:
         X, active_set, E = l21_solver(
             M, G, alpha, lc, maxit=maxit, tol=tol, n_orient=n_orient, init=None
@@ -640,8 +640,8 @@ def iterative_mixed_norm_solver(
 
     if weight_init is not None and weight_init.shape != (G.shape[1],):
         raise ValueError(
-            "Wrong dimension for weight initialization. Got %s. "
-            "Expected %s." % (weight_init.shape, (G.shape[1],))
+            f"Wrong dimension for weight initialization. Got {weight_init.shape}. "
+            f"Expected {(G.shape[1],)}."
         )
 
     weights = weight_init if weight_init is not None else np.ones(G.shape[1])
@@ -778,7 +778,7 @@ def safe_max_abs_diff(A, ia, B, ib):
 class _Phi:
     """Have phi stft as callable w/o using a lambda that does not pickle."""
 
-    def __init__(self, wsize, tstep, n_coefs, n_times):  # noqa: D102
+    def __init__(self, wsize, tstep, n_coefs, n_times):
         self.wsize = np.atleast_1d(wsize)
         self.tstep = np.atleast_1d(tstep)
         self.n_coefs = np.atleast_1d(n_coefs)
@@ -799,7 +799,7 @@ class _Phi:
         else:
             return np.hstack([x @ op for op in self.ops]) / np.sqrt(self.n_dicts)
 
-    def norm(self, z, ord=2):
+    def norm(self, z, ord=2):  # noqa: A002
         """Squared L2 norm if ord == 2 and L1 norm if order == 1."""
         if ord not in (1, 2):
             raise ValueError(
@@ -819,7 +819,7 @@ class _Phi:
 class _PhiT:
     """Have phi.T istft as callable w/o using a lambda that does not pickle."""
 
-    def __init__(self, tstep, n_freqs, n_steps, n_times):  # noqa: D102
+    def __init__(self, tstep, n_freqs, n_steps, n_times):
         self.tstep = tstep
         self.n_freqs = n_freqs
         self.n_steps = n_steps
@@ -977,9 +977,9 @@ def norm_epsilon(Y, l1_ratio, phi, w_space=1.0, w_time=None):
         p_sum_w2 = np.cumsum(w_time**2)
         p_sum_Yw = np.cumsum(Y * w_time)
         upper = p_sum_Y2 / (Y / w_time) ** 2 - 2.0 * p_sum_Yw / (Y / w_time) + p_sum_w2
-    upper_greater = np.where(
-        upper > w_space**2 * (1.0 - l1_ratio) ** 2 / l1_ratio**2
-    )[0]
+    upper_greater = np.where(upper > w_space**2 * (1.0 - l1_ratio) ** 2 / l1_ratio**2)[
+        0
+    ]
 
     i0 = upper_greater[0] - 1 if upper_greater.size else K - 1
 
@@ -1270,7 +1270,7 @@ def _tf_mixed_norm_solver_bcd_(
                 "\n    Iteration %d :: n_active %d"
                 % (i + 1, np.sum(active_set) / n_orient)
             )
-            logger.info("    dgap %.2e :: p_obj %f :: d_obj %f" % (gap, p_obj, d_obj))
+            logger.info(f"    dgap {gap:.2e} :: p_obj {p_obj} :: d_obj {d_obj}")
 
         if converged:
             break
@@ -1504,7 +1504,7 @@ def tf_mixed_norm_solver(
     if len(tstep) != len(wsize):
         raise ValueError(
             "The same number of window sizes and steps must be "
-            "passed. Got tstep = %s and wsize = %s" % (tstep, wsize)
+            f"passed. Got tstep = {tstep} and wsize = {wsize}"
         )
 
     n_steps = np.ceil(M.shape[1] / tstep.astype(float)).astype(int)
@@ -1624,7 +1624,7 @@ def iterative_tf_mixed_norm_solver(
     if len(tstep) != len(wsize):
         raise ValueError(
             "The same number of window sizes and steps must be "
-            "passed. Got tstep = %s and wsize = %s" % (tstep, wsize)
+            f"passed. Got tstep = {tstep} and wsize = {wsize}"
         )
 
     n_steps = np.ceil(n_times / tstep.astype(float)).astype(int)
