@@ -111,7 +111,7 @@ class RawBrainVision(BaseRaw):
 
         orig_format = "single" if isinstance(fmt, dict) else fmt
         raw_extras = dict(offsets=offsets, fmt=fmt, order=order, n_samples=n_samples)
-        super(RawBrainVision, self).__init__(
+        super().__init__(
             info,
             last_samps=[n_samples - 1],
             filenames=[data_fname],
@@ -124,7 +124,7 @@ class RawBrainVision(BaseRaw):
 
         self.set_montage(montage)
 
-        settings, cfg, cinfo, _ = _aux_hdr_info(hdr_fname)
+        settings, _, _, _ = _aux_hdr_info(hdr_fname)
         split_settings = settings.splitlines()
         self.impedances = _parse_impedance(split_settings, self.info["meas_date"])
 
@@ -344,9 +344,10 @@ def _read_annotations_brainvision(fname, sfreq="auto"):
 
 def _check_bv_version(header, kind):
     """Check the header version."""
-    _data_err = """\
-    MNE-Python currently only supports %s versions 1.0 and 2.0, got unparsable\
-     %r. Contact MNE-Python developers for support."""
+    _data_err = (
+        "MNE-Python currently only supports %s versions 1.0 and 2.0, got unparsable "
+        "%r. Contact MNE-Python developers for support."
+    )
     # optional space, optional Core or V-Amp, optional Exchange,
     # Version/Header, optional comma, 1/2
     _data_re = (
@@ -355,14 +356,15 @@ def _check_bv_version(header, kind):
 
     assert kind in ("header", "marker")
 
-    if header == "":
-        warn(f"Missing header in {kind} file.")
     for version in range(1, 3):
         this_re = _data_re % (kind.capitalize(), version)
         if re.search(this_re, header) is not None:
             return version
     else:
-        warn(_data_err % (kind, header))
+        if header == "":
+            warn(f"Missing header in {kind} file.")
+        else:
+            warn(_data_err % (kind, header))
 
 
 _orientation_dict = dict(MULTIPLEXED="F", VECTORIZED="C")
@@ -445,7 +447,7 @@ def _aux_hdr_info(hdr_fname):
         params, settings = settings.split("[Comment]")
     else:
         params, settings = settings, ""
-    cfg = configparser.ConfigParser()
+    cfg = configparser.ConfigParser(interpolation=None)
     with StringIO(params) as fid:
         cfg.read_file(fid)
 
@@ -542,7 +544,7 @@ def _get_hdr_info(hdr_fname, eog, misc, scale):
     # Try to get measurement date from marker file
     # Usually saved with a marker "New Segment", see BrainVision documentation
     regexp = r"^Mk\d+=New Segment,.*,\d+,\d+,-?\d+,(\d{20})$"
-    with open(mrk_fname, "r") as tmp_mrk_f:
+    with open(mrk_fname) as tmp_mrk_f:
         lines = tmp_mrk_f.readlines()
 
     for line in lines:
@@ -636,7 +638,7 @@ def _get_hdr_info(hdr_fname, eog, misc, scale):
             ch_name = ch_dict[ch[0]]
             montage_names.append(ch_name)
             # 1: radius, 2: theta, 3: phi
-            rad, theta, phi = [float(c) for c in ch[1].split(",")]
+            rad, theta, phi = (float(c) for c in ch[1].split(","))
             pol = np.deg2rad(theta)
             az = np.deg2rad(phi)
             # Coordinates could be "idealized" (spherical head model)
@@ -656,9 +658,9 @@ def _get_hdr_info(hdr_fname, eog, misc, scale):
         if len(to_misc) > 0:
             misc += to_misc
             warn(
-                "No coordinate information found for channels {}. "
-                "Setting channel types to misc. To avoid this warning, set "
-                "channel types explicitly.".format(to_misc)
+                f"No coordinate information found for channels {to_misc}. Setting "
+                "channel types to misc. To avoid this warning, set channel types "
+                "explicitly."
             )
 
     if np.isnan(cals).any():
@@ -865,8 +867,8 @@ def _get_hdr_info(hdr_fname, eog, misc, scale):
                     nyquist = ""
                 warn(
                     "Channels contain different lowpass filters. "
-                    "Highest (weakest) filter setting (%0.2f Hz%s) "
-                    "will be stored." % (info["lowpass"], nyquist)
+                    f"Highest (weakest) filter setting ({info['lowpass']:0.2f} "
+                    f"Hz{nyquist}) will be stored."
                 )
 
     # Creates a list of dicts of eeg channels for raw.info
@@ -921,7 +923,7 @@ def read_raw_brainvision(
     scale=1.0,
     preload=False,
     verbose=None,
-):
+) -> RawBrainVision:
     """Reader for Brain Vision EEG file.
 
     Parameters
@@ -988,9 +990,7 @@ class _BVEventParser(_DefaultEventParser):
         elif description in _OTHER_ACCEPTED_MARKERS:
             code = _OTHER_ACCEPTED_MARKERS[description]
         else:
-            code = super(_BVEventParser, self).__call__(
-                description, offset=_OTHER_OFFSET
-            )
+            code = super().__call__(description, offset=_OTHER_OFFSET)
         return code
 
 
