@@ -33,7 +33,7 @@ from .trans import _make_ctf_coord_trans_set
 @fill_doc
 def read_raw_ctf(
     directory, system_clock="truncate", preload=False, clean_names=False, verbose=None
-):
+) -> "RawCTF":
     """Raw object from CTF directory.
 
     Parameters
@@ -55,11 +55,6 @@ def read_raw_ctf(
     -------
     raw : instance of RawCTF
         The raw data.
-        See :class:`mne.io.Raw` for documentation of attributes and methods.
-
-    See Also
-    --------
-    mne.io.Raw : Documentation of attributes and methods of RawCTF.
 
     Notes
     -----
@@ -111,7 +106,7 @@ class RawCTF(BaseRaw):
         preload=False,
         verbose=None,
         clean_names=False,
-    ):  # noqa: D102
+    ):
         # adapted from mne_ctf2fiff.c
         directory = str(
             _check_fname(directory, "read", True, "directory", need_dir=True)
@@ -169,7 +164,7 @@ class RawCTF(BaseRaw):
                 f"file(s): {missing_names}, and the following file(s) had no "
                 f"valid samples: {no_samps}"
             )
-        super(RawCTF, self).__init__(
+        super().__init__(
             info,
             preload,
             first_samps=first_samps,
@@ -232,7 +227,7 @@ def _clean_names_inst(inst):
 
 def _get_sample_info(fname, res4, system_clock):
     """Determine the number of valid samples."""
-    logger.info("Finding samples for %s: " % (fname,))
+    logger.info(f"Finding samples for {fname}: ")
     if CTF.SYSTEM_CLOCK_CH in res4["ch_names"]:
         clock_ch = res4["ch_names"].index(CTF.SYSTEM_CLOCK_CH)
     else:
