@@ -197,10 +197,10 @@ def _read_curry_parameters(fname):
             if any(var_name in line for var_name in var_names):
                 key, val = line.replace(" ", "").replace("\n", "").split("=")
                 param_dict[key.lower().replace("_", "")] = val
-            for type in CHANTYPES:
-                if "DEVICE_PARAMETERS" + CHANTYPES[type] + " START" in line:
+            for key, type_ in CHANTYPES.items():
+                if f"DEVICE_PARAMETERS{type_} START" in line:
                     data_unit = next(fid)
-                    unit_dict[type] = (
+                    unit_dict[key] = (
                         data_unit.replace(" ", "").replace("\n", "").split("=")[-1]
                     )
 
@@ -425,7 +425,7 @@ def _make_trans_dig(curry_paths, info, curry_dev_dev_t):
             )
         )
         dist = 1000 * np.linalg.norm(unknown_curry_t["trans"][:3, 3])
-        logger.info("   Fit a %0.1f° rotation, %0.1f mm translation" % (angle, dist))
+        logger.info(f"   Fit a {angle:0.1f}° rotation, {dist:0.1f} mm translation")
         unknown_dev_t = combine_transforms(
             unknown_curry_t, curry_dev_dev_t, "unknown", "meg"
         )
@@ -464,7 +464,7 @@ def _make_trans_dig(curry_paths, info, curry_dev_dev_t):
 
 def _first_hpi(fname):
     # Get the first HPI result
-    with open(fname, "r") as fid:
+    with open(fname) as fid:
         for line in fid:
             line = line.strip()
             if any(x in line for x in ("FileVersion", "NumCoils")) or not line:
@@ -472,7 +472,7 @@ def _first_hpi(fname):
             hpi = np.array(line.split(), float)
             break
         else:
-            raise RuntimeError("Could not find valid HPI in %s" % (fname,))
+            raise RuntimeError(f"Could not find valid HPI in {fname}")
     # t is the first entry
     assert hpi.ndim == 1
     hpi = hpi[1:]
@@ -542,7 +542,7 @@ def _read_annotations_curry(fname, sfreq="auto"):
 
 
 @verbose
-def read_raw_curry(fname, preload=False, verbose=None):
+def read_raw_curry(fname, preload=False, verbose=None) -> "RawCurry":
     """Read raw data from Curry files.
 
     Parameters
@@ -596,7 +596,7 @@ class RawCurry(BaseRaw):
         last_samps = [n_samples - 1]
         raw_extras = dict(is_ascii=is_ascii)
 
-        super(RawCurry, self).__init__(
+        super().__init__(
             info,
             preload,
             filenames=[data_fname],
