@@ -325,7 +325,7 @@ def test_check_missing_files():
 
 
 def _mock_info_file(src, dst, sfreq, time_step):
-    with open(src, "r") as in_file, open(dst, "w") as out_file:
+    with open(src) as in_file, open(dst, "w") as out_file:
         for line in in_file:
             if "SampleFreqHz" in line:
                 out_file.write(line.replace("500", str(sfreq)))
