@@ -52,8 +52,6 @@ def _check_eeglab_fname(fname, dataname):
             "Old data format .dat detected. Please update your EEGLAB "
             "version and resave the data in .fdt format"
         )
-    elif fmt != ".fdt":
-        raise OSError("Expected .fdt file format. Found %s format" % fmt)
 
     basedir = op.dirname(fname)
     data_fname = op.join(basedir, dataname)
@@ -293,7 +291,7 @@ def read_raw_eeglab(
     uint16_codec=None,
     montage_units="auto",
     verbose=None,
-):
+) -> "RawEEGLAB":
     r"""Read an EEGLAB .set file.
 
     Parameters
@@ -349,7 +347,7 @@ def read_epochs_eeglab(
     uint16_codec=None,
     montage_units="auto",
     verbose=None,
-):
+) -> "EpochsEEGLAB":
     r"""Reader function for EEGLAB epochs files.
 
     Parameters
@@ -449,7 +447,7 @@ class RawEEGLAB(BaseRaw):
         uint16_codec=None,
         montage_units="auto",
         verbose=None,
-    ):  # noqa: D102
+    ):
         input_fname = str(_check_fname(input_fname, "read", True, "input_fname"))
         eeg = _check_load_mat(input_fname, uint16_codec)
         if eeg.trials != 1:
@@ -467,7 +465,7 @@ class RawEEGLAB(BaseRaw):
             data_fname = _check_eeglab_fname(input_fname, eeg.data)
             logger.info("Reading %s" % data_fname)
 
-            super(RawEEGLAB, self).__init__(
+            super().__init__(
                 info,
                 preload,
                 filenames=[data_fname],
@@ -491,7 +489,7 @@ class RawEEGLAB(BaseRaw):
             data = np.empty((n_chan, n_times), dtype=float)
             data[:n_chan] = eeg.data
             data *= CAL
-            super(RawEEGLAB, self).__init__(
+            super().__init__(
                 info,
                 data,
                 filenames=[input_fname],
@@ -602,7 +600,7 @@ class EpochsEEGLAB(BaseEpochs):
         uint16_codec=None,
         montage_units="auto",
         verbose=None,
-    ):  # noqa: D102
+    ):
         input_fname = str(
             _check_fname(fname=input_fname, must_exist=True, overwrite="read")
         )
@@ -694,7 +692,7 @@ class EpochsEEGLAB(BaseEpochs):
         assert data.shape == (eeg.trials, eeg.nbchan, eeg.pnts)
         tmin, tmax = eeg.xmin, eeg.xmax
 
-        super(EpochsEEGLAB, self).__init__(
+        super().__init__(
             info,
             data,
             events,
@@ -799,6 +797,22 @@ def _read_annotations_eeglab(eeg, uint16_codec=None):
             )
             duration[idx] = np.nan if is_empty_array else event.duration
 
+    # Drop events with NaN onset see PR #12484
+    valid_indices = [
+        idx for idx, onset_idx in enumerate(onset) if not np.isnan(onset_idx)
+    ]
+    n_dropped = len(onset) - len(valid_indices)
+    if len(valid_indices) != len(onset):
+        warn(
+            f"{n_dropped} events have an onset that is NaN. These values are "
+            "usually ignored by EEGLAB and will be dropped from the "
+            "annotations."
+        )
+
+    onset = np.array([onset[idx] for idx in valid_indices])
+    duration = np.array([duration[idx] for idx in valid_indices])
+    description = [description[idx] for idx in valid_indices]
+
     return Annotations(
         onset=np.array(onset) / eeg.srate,
         duration=duration / eeg.srate,
