@@ -64,7 +64,7 @@ def _read_mff_header(filepath):
         record_time,
     )
     if g is None:
-        raise RuntimeError("Could not parse recordTime %r" % (record_time,))
+        raise RuntimeError(f"Could not parse recordTime {repr(record_time)}")
     frac = g.groups()[0]
     assert len(frac) in (6, 9) and all(f.isnumeric() for f in frac)  # regex
     div = 1000 if len(frac) == 6 else 1000000
@@ -72,7 +72,7 @@ def _read_mff_header(filepath):
         # convert from times in µS to samples
         for ei, e in enumerate(epochs[key]):
             if e % div != 0:
-                raise RuntimeError("Could not parse epoch time %s" % (e,))
+                raise RuntimeError(f"Could not parse epoch time {e}")
             epochs[key][ei] = e // div
         epochs[key] = np.array(epochs[key], np.uint64)
         # I guess they refer to times in milliseconds?
@@ -104,7 +104,7 @@ def _read_mff_header(filepath):
     if bad:
         raise RuntimeError(
             "EGI epoch first/last samps could not be parsed:\n"
-            "%s\n%s" % (list(epochs["first_samps"]), list(epochs["last_samps"]))
+            f'{list(epochs["first_samps"])}\n{list(epochs["last_samps"])}'
         )
     summaryinfo.update(epochs)
     # index which samples in raw are actually readable from disk (i.e., not
@@ -156,7 +156,7 @@ def _read_mff_header(filepath):
         if not same_blocks:
             raise RuntimeError(
                 "PNS and signals samples did not match:\n"
-                "%s\nvs\n%s" % (list(pns_samples), list(signal_samples))
+                f"{list(pns_samples)}\nvs\n{list(signal_samples)}"
             )
 
         pns_file = op.join(filepath, "pnsSet.xml")
@@ -647,7 +647,7 @@ class RawMff(BaseRaw):
         self._filenames = [file_bin]
         self._raw_extras = [egi_info]
 
-        super(RawMff, self).__init__(
+        super().__init__(
             info,
             preload=preload,
             orig_format="single",
