@@ -185,7 +185,7 @@ def get_epochs(system):
         else:
             event_id = [int(cfg_local["eventvalue"])]
 
-        event_id = [id for id in event_id if id in events[:, 2]]
+        event_id = [id_ for id_ in event_id if id_ in events[:, 2]]
 
     epochs = mne.Epochs(
         raw_data,
