@@ -16,7 +16,7 @@ import numpy as np
 from ..._fiff.constants import FIFF
 from ..._fiff.meas_info import read_meas_info
 from ..._fiff.open import _fiff_get_fid, _get_next_fname, fiff_open
-from ..._fiff.tag import read_tag, read_tag_info
+from ..._fiff.tag import _call_dict, read_tag
 from ..._fiff.tree import dir_tree_find
 from ..._fiff.utils import _mult_cal_one
 from ...annotations import Annotations, _read_annotations_fif
@@ -97,7 +97,7 @@ class Raw(BaseRaw):
         preload=False,
         on_split_missing="raise",
         verbose=None,
-    ):  # noqa: D102
+    ):
         raws = []
         do_check_ext = not _file_like(fname)
         next_fname = fname
@@ -124,7 +124,7 @@ class Raw(BaseRaw):
             fname = None  # noqa
 
         _check_raw_compatibility(raws)
-        super(Raw, self).__init__(
+        super().__init__(
             copy.deepcopy(raws[0].info),
             False,
             [r.first_samp for r in raws],
@@ -255,48 +255,40 @@ class Raw(BaseRaw):
             nskip = 0
             orig_format = None
 
+            _byte_dict = {
+                FIFF.FIFFT_DAU_PACK16: 2,
+                FIFF.FIFFT_SHORT: 2,
+                FIFF.FIFFT_FLOAT: 4,
+                FIFF.FIFFT_DOUBLE: 8,
+                FIFF.FIFFT_INT: 4,
+                FIFF.FIFFT_COMPLEX_FLOAT: 8,
+                FIFF.FIFFT_COMPLEX_DOUBLE: 16,
+            }
+            _orig_format_dict = {
+                FIFF.FIFFT_DAU_PACK16: "short",
+                FIFF.FIFFT_SHORT: "short",
+                FIFF.FIFFT_FLOAT: "single",
+                FIFF.FIFFT_DOUBLE: "double",
+                FIFF.FIFFT_INT: "int",
+                FIFF.FIFFT_COMPLEX_FLOAT: "single",
+                FIFF.FIFFT_COMPLEX_DOUBLE: "double",
+            }
+
             for k in range(first, nent):
                 ent = directory[k]
                 # There can be skips in the data (e.g., if the user unclicked)
                 # an re-clicked the button
-                if ent.kind == FIFF.FIFF_DATA_SKIP:
-                    tag = read_tag(fid, ent.pos)
-                    nskip = int(tag.data.item())
-                elif ent.kind == FIFF.FIFF_DATA_BUFFER:
+                if ent.kind == FIFF.FIFF_DATA_BUFFER:
                     #   Figure out the number of samples in this buffer
-                    if ent.type == FIFF.FIFFT_DAU_PACK16:
-                        nsamp = ent.size // (2 * nchan)
-                    elif ent.type == FIFF.FIFFT_SHORT:
-                        nsamp = ent.size // (2 * nchan)
-                    elif ent.type == FIFF.FIFFT_FLOAT:
-                        nsamp = ent.size // (4 * nchan)
-                    elif ent.type == FIFF.FIFFT_DOUBLE:
-                        nsamp = ent.size // (8 * nchan)
-                    elif ent.type == FIFF.FIFFT_INT:
-                        nsamp = ent.size // (4 * nchan)
-                    elif ent.type == FIFF.FIFFT_COMPLEX_FLOAT:
-                        nsamp = ent.size // (8 * nchan)
-                    elif ent.type == FIFF.FIFFT_COMPLEX_DOUBLE:
-                        nsamp = ent.size // (16 * nchan)
-                    else:
-                        raise ValueError(
-                            "Cannot handle data buffers of type " "%d" % ent.type
-                        )
+                    try:
+                        div = _byte_dict[ent.type]
+                    except KeyError:
+                        raise RuntimeError(
+                            f"Cannot handle data buffers of type {ent.type}"
+                        ) from None
+                    nsamp = ent.size // (div * nchan)
                     if orig_format is None:
-                        if ent.type == FIFF.FIFFT_DAU_PACK16:
-                            orig_format = "short"
-                        elif ent.type == FIFF.FIFFT_SHORT:
-                            orig_format = "short"
-                        elif ent.type == FIFF.FIFFT_FLOAT:
-                            orig_format = "single"
-                        elif ent.type == FIFF.FIFFT_DOUBLE:
-                            orig_format = "double"
-                        elif ent.type == FIFF.FIFFT_INT:
-                            orig_format = "int"
-                        elif ent.type == FIFF.FIFFT_COMPLEX_FLOAT:
-                            orig_format = "single"
-                        elif ent.type == FIFF.FIFFT_COMPLEX_DOUBLE:
-                            orig_format = "double"
+                        orig_format = _orig_format_dict[ent.type]
 
                     #  Do we have an initial skip pending?
                     if first_skip > 0:
@@ -327,6 +319,9 @@ class Raw(BaseRaw):
                         )
                     )
                     first_samp += nsamp
+                elif ent.kind == FIFF.FIFF_DATA_SKIP:
+                    tag = read_tag(fid, ent.pos)
+                    nskip = int(tag.data.item())
 
             next_fname = _get_next_fname(fid, fname_rep, tree)
 
@@ -381,22 +376,17 @@ class Raw(BaseRaw):
         if self._dtype_ is not None:
             return self._dtype_
         dtype = None
-        for raw_extra, filename in zip(self._raw_extras, self._filenames):
+        for raw_extra in self._raw_extras:
             for ent in raw_extra["ent"]:
                 if ent is not None:
-                    with _fiff_get_fid(filename) as fid:
-                        fid.seek(ent.pos, 0)
-                        tag = read_tag_info(fid)
-                        if tag is not None:
-                            if tag.type in (
-                                FIFF.FIFFT_COMPLEX_FLOAT,
-                                FIFF.FIFFT_COMPLEX_DOUBLE,
-                            ):
-                                dtype = np.complex128
-                            else:
-                                dtype = np.float64
-                    if dtype is not None:
-                        break
+                    if ent.type in (
+                        FIFF.FIFFT_COMPLEX_FLOAT,
+                        FIFF.FIFFT_COMPLEX_DOUBLE,
+                    ):
+                        dtype = np.complex128
+                    else:
+                        dtype = np.float64
+                    break
             if dtype is not None:
                 break
         if dtype is None:
@@ -421,27 +411,31 @@ class Raw(BaseRaw):
                 first_pick = max(start - first, 0)
                 last_pick = min(nsamp, stop - first)
                 picksamp = last_pick - first_pick
-                # only read data if it exists
-                if ent is not None:
-                    one = read_tag(
-                        fid,
-                        ent.pos,
-                        shape=(nsamp, nchan),
-                        rlims=(first_pick, last_pick),
-                    ).data
-                    try:
-                        one.shape = (picksamp, nchan)
-                    except AttributeError:  # one is None
-                        n_bad += picksamp
-                    else:
-                        _mult_cal_one(
-                            data[:, offset : (offset + picksamp)],
-                            one.T,
-                            idx,
-                            cals,
-                            mult,
-                        )
+                this_start = offset
                 offset += picksamp
+                this_stop = offset
+                # only read data if it exists
+                if ent is None:
+                    continue  # just use zeros for gaps
+                # faster to always read full tag, taking advantage of knowing the header
+                # already (cutting out some of read_tag) ...
+                fid.seek(ent.pos + 16, 0)
+                one = _call_dict[ent.type](fid, ent, shape=None, rlims=None)
+                try:
+                    one.shape = (nsamp, nchan)
+                except AttributeError:  # one is None
+                    n_bad += picksamp
+                else:
+                    # ... then pick samples we want
+                    if first_pick != 0 or last_pick != nsamp:
+                        one = one[first_pick:last_pick]
+                    _mult_cal_one(
+                        data[:, this_start:this_stop],
+                        one.T,
+                        idx,
+                        cals,
+                        mult,
+                    )
             if n_bad:
                 warn(
                     f"FIF raw buffer could not be read, acquisition error "
@@ -502,7 +496,7 @@ def _check_entry(first, nent):
 @fill_doc
 def read_raw_fif(
     fname, allow_maxshield=False, preload=False, on_split_missing="raise", verbose=None
-):
+) -> Raw:
     """Reader function for Raw FIF data.
 
     Parameters
