@@ -43,7 +43,7 @@ UINT32 = "<u4"
 INT32 = "<i4"
 
 
-def _call_digitization(info, mrk, elp, hsp, kit_info):
+def _call_digitization(info, mrk, elp, hsp, kit_info, *, bad_coils=()):
     # Use values from kit_info only if all others are None
     if mrk is None and elp is None and hsp is None:
         mrk = kit_info.get("mrk", None)
@@ -62,7 +62,11 @@ def _call_digitization(info, mrk, elp, hsp, kit_info):
     if mrk is not None and elp is not None and hsp is not None:
         with info._unlock():
             info["dig"], info["dev_head_t"], info["hpi_results"] = _set_dig_kit(
-                mrk, elp, hsp, kit_info["eeg_dig"]
+                mrk,
+                elp,
+                hsp,
+                kit_info["eeg_dig"],
+                bad_coils=bad_coils,
             )
     elif mrk is not None or elp is not None or hsp is not None:
         raise ValueError(
@@ -75,7 +79,7 @@ def _call_digitization(info, mrk, elp, hsp, kit_info):
 class UnsupportedKITFormat(ValueError):
     """Our reader is not guaranteed to work with old files."""
 
-    def __init__(self, sqd_version, *args, **kwargs):  # noqa: D102
+    def __init__(self, sqd_version, *args, **kwargs):
         self.sqd_version = sqd_version
         ValueError.__init__(self, *args, **kwargs)
 
@@ -100,6 +104,7 @@ class RawKIT(BaseRaw):
         Force reading old data that is not officially supported. Alternatively,
         read and re-save the data with the KIT MEG Laboratory application.
     %(standardize_names)s
+    %(kit_badcoils)s
     %(verbose)s
 
     Notes
@@ -133,8 +138,10 @@ class RawKIT(BaseRaw):
         stim_code="binary",
         allow_unknown_format=False,
         standardize_names=None,
+        *,
+        bad_coils=(),
         verbose=None,
-    ):  # noqa: D102
+    ):
         logger.info("Extracting SQD Parameters from %s..." % input_fname)
         input_fname = op.abspath(input_fname)
         self.preload = False
@@ -151,7 +158,7 @@ class RawKIT(BaseRaw):
         last_samps = [kit_info["n_samples"] - 1]
         self._raw_extras = [kit_info]
         _set_stimchannels(self, info, stim, stim_code)
-        super(RawKIT, self).__init__(
+        super().__init__(
             info,
             preload,
             last_samps=last_samps,
@@ -160,7 +167,12 @@ class RawKIT(BaseRaw):
             verbose=verbose,
         )
         self.info = _call_digitization(
-            info=self.info, mrk=mrk, elp=elp, hsp=hsp, kit_info=kit_info
+            info=self.info,
+            mrk=mrk,
+            elp=elp,
+            hsp=hsp,
+            kit_info=kit_info,
+            bad_coils=bad_coils,
         )
         logger.info("Ready.")
 
@@ -382,7 +394,7 @@ class EpochsKIT(BaseEpochs):
         allow_unknown_format=False,
         standardize_names=None,
         verbose=None,
-    ):  # noqa: D102
+    ):
         if isinstance(events, (str, PathLike, Path)):
             events = read_events(events)
 
@@ -422,7 +434,7 @@ class EpochsKIT(BaseEpochs):
             self._raw_extras[0]["frame_length"],
         )
         tmax = ((data.shape[2] - 1) / self.info["sfreq"]) + tmin
-        super(EpochsKIT, self).__init__(
+        super().__init__(
             self.info,
             data,
             events,
@@ -535,9 +547,8 @@ def get_kit_info(rawfile, allow_unknown_format, standardize_names=None, verbose=
             else:
                 raise UnsupportedKITFormat(
                     version_string,
-                    "SQD file format %s is not officially supported. "
-                    "Set allow_unknown_format=True to load it anyways."
-                    % (version_string,),
+                    f"SQD file format {version_string} is not officially supported. "
+                    "Set allow_unknown_format=True to load it anyways.",
                 )
 
         sysid = np.fromfile(fid, INT32, 1)[0]
@@ -912,8 +923,10 @@ def read_raw_kit(
     stim_code="binary",
     allow_unknown_format=False,
     standardize_names=False,
+    *,
+    bad_coils=(),
     verbose=None,
-):
+) -> RawKIT:
     r"""Reader function for Ricoh/KIT conversion to FIF.
 
     Parameters
@@ -932,6 +945,7 @@ def read_raw_kit(
         Force reading old data that is not officially supported. Alternatively,
         read and re-save the data with the KIT MEG Laboratory application.
     %(standardize_names)s
+    %(kit_badcoils)s
     %(verbose)s
 
     Returns
@@ -966,6 +980,7 @@ def read_raw_kit(
         stim_code=stim_code,
         allow_unknown_format=allow_unknown_format,
         standardize_names=standardize_names,
+        bad_coils=bad_coils,
         verbose=verbose,
     )
 
@@ -981,7 +996,7 @@ def read_epochs_kit(
     allow_unknown_format=False,
     standardize_names=False,
     verbose=None,
-):
+) -> EpochsKIT:
     """Reader function for Ricoh/KIT epochs files.
 
     Parameters
