@@ -34,7 +34,9 @@ from ._localized_abbr import _localized_abbr
 
 
 @fill_doc
-def read_raw_nirx(fname, saturated="annotate", preload=False, verbose=None):
+def read_raw_nirx(
+    fname, saturated="annotate", preload=False, verbose=None
+) -> "RawNIRX":
     """Reader for a NIRX fNIRS recording.
 
     Parameters
@@ -63,7 +65,7 @@ def read_raw_nirx(fname, saturated="annotate", preload=False, verbose=None):
 
 
 def _open(fname):
-    return open(fname, "r", encoding="latin-1")
+    return open(fname, encoding="latin-1")
 
 
 @fill_doc
@@ -99,7 +101,7 @@ class RawNIRX(BaseRaw):
 
         fname = str(_check_fname(fname, "read", True, "fname", need_dir=True))
 
-        json_config = glob.glob("%s/*%s" % (fname, "config.json"))
+        json_config = glob.glob(f"{fname}/*{'config.json'}")
         if len(json_config):
             is_aurora = True
         else:
@@ -128,7 +130,7 @@ class RawNIRX(BaseRaw):
                 "config.txt",
                 "probeInfo.mat",
             )
-            n_dat = len(glob.glob("%s/*%s" % (fname, "dat")))
+            n_dat = len(glob.glob(f"{fname}/*{'dat'}"))
             if n_dat != 1:
                 warn(
                     "A single dat file was expected in the specified path, "
@@ -141,7 +143,7 @@ class RawNIRX(BaseRaw):
         files = dict()
         nan_mask = dict()
         for key in keys:
-            files[key] = glob.glob("%s/*%s" % (fname, key))
+            files[key] = glob.glob(f"{fname}/*{key}")
             fidx = 0
             if len(files[key]) != 1:
                 if key not in ("wl1", "wl2"):
@@ -200,7 +202,7 @@ class RawNIRX(BaseRaw):
             if hdr["GeneralInfo"]["NIRStar"] not in ['"15.0"', '"15.2"', '"15.3"']:
                 raise RuntimeError(
                     "MNE does not support this NIRStar version"
-                    " (%s)" % (hdr["GeneralInfo"]["NIRStar"],)
+                    f" ({hdr['GeneralInfo']['NIRStar']})"
                 )
             if (
                 "NIRScout" not in hdr["GeneralInfo"]["Device"]
@@ -474,7 +476,7 @@ class RawNIRX(BaseRaw):
                 annot_mask |= mask
                 nan_mask[key] = None  # shouldn't need again
 
-        super(RawNIRX, self).__init__(
+        super().__init__(
             info,
             preload,
             filenames=[fname],
