@@ -4,7 +4,6 @@
 # Copyright the MNE-Python contributors.
 
 
-from .._fiff import _io_dep_getattr
 from .._fiff.pick import (
     _DATA_CH_TYPES_ORDER_DEFAULT,
     _DATA_CH_TYPES_SPLIT,
@@ -18,11 +17,3 @@ __all__ = [
     "_DATA_CH_TYPES_ORDER_DEFAULT",
     "_DATA_CH_TYPES_SPLIT",
 ]
-
-
-def __getattr__(name):
-    try:
-        return globals()[name]
-    except KeyError:
-        pass
-    return _io_dep_getattr(name, "pick")
