@@ -8,7 +8,7 @@ from mne import pick_types
 from mne.io import read_raw_fif
 from mne.preprocessing import create_ecg_epochs, find_ecg_events
 
-data_path = Path(__file__).parent.parent.parent / "io" / "tests" / "data"
+data_path = Path(__file__).parents[2] / "io" / "tests" / "data"
 raw_fname = data_path / "test_raw.fif"
 event_fname = data_path / "test-eve.fif"
 proj_fname = data_path / "test-proj.fif"
