@@ -77,9 +77,9 @@ def test_mne_python_vs_eeglab():
         Y = generate_data_for_comparing_against_eeglab_infomax(ch_type, random_state)
         N, T = Y.shape
         for method in methods:
-            eeglab_results_file = "eeglab_%s_results_%s_data.mat" % (
-                method,
-                dict(eeg="eeg", mag="meg")[ch_type],
+            eeglab_results_file = (
+                f"eeglab_{method}_results_"
+                f"{dict(eeg='eeg', mag='meg')[ch_type]}_data.mat"
             )
 
             # For comparison against eeglab, make sure the following
@@ -171,9 +171,7 @@ def test_mne_python_vs_eeglab():
             sources = np.dot(unmixing, Y)
             mixing = pinv(unmixing)
 
-            mvar = (
-                np.sum(mixing**2, axis=0) * np.sum(sources**2, axis=1) / (N * T - 1)
-            )
+            mvar = np.sum(mixing**2, axis=0) * np.sum(sources**2, axis=1) / (N * T - 1)
             windex = np.argsort(mvar)[::-1]
 
             unmixing_ordered = unmixing[windex, :]
