@@ -58,7 +58,7 @@ from mne.utils import (
     use_log_level,
 )
 
-io_path = Path(__file__).parent.parent.parent / "io" / "tests" / "data"
+io_path = Path(__file__).parents[2] / "io" / "tests" / "data"
 raw_small_fname = io_path / "test_raw.fif"
 
 data_path = testing.data_path(download=False)
@@ -122,7 +122,7 @@ tri_sss_ctc_cal_reg_in_fname = triux_path / "triux_bmlhus_erm_ctc_cal_regIn_raw_
 tri_ctc_fname = triux_path / "ct_sparse_BMLHUS.fif"
 tri_cal_fname = triux_path / "sss_cal_BMLHUS.dat"
 
-io_dir = Path(__file__).parent.parent.parent / "io"
+io_dir = Path(__file__).parents[2] / "io"
 fname_ctf_raw = io_dir / "tests" / "data" / "test_ctf_comp_raw.fif"
 ctf_fname_continuous = data_path / "CTF" / "testdata_ctf.ds"
 
@@ -173,11 +173,7 @@ def _assert_n_free(raw_sss, lower, upper=None):
     """Check the DOF."""
     upper = lower if upper is None else upper
     n_free = raw_sss.info["proc_history"][0]["max_info"]["sss_info"]["nfree"]
-    assert lower <= n_free <= upper, "nfree fail: %s <= %s <= %s" % (
-        lower,
-        n_free,
-        upper,
-    )
+    assert lower <= n_free <= upper, f"nfree fail: {lower} <= {n_free} <= {upper}"
 
 
 def _assert_mag_coil_type(info, coil_type):
@@ -730,7 +726,8 @@ def test_spatiotemporal_only():
     raw_tsss = maxwell_filter(raw, st_duration=tmax, st_correlation=1.0, st_only=True)
     assert_allclose(raw[:][0], raw_tsss[:][0])
     # degenerate
-    pytest.raises(ValueError, maxwell_filter, raw, st_only=True)  # no ST
+    with pytest.raises(ValueError, match="must not be None if st_only"):
+        maxwell_filter(raw, st_only=True)
     # two-step process equivalent to single-step process
     raw_tsss = maxwell_filter(raw, st_duration=tmax, st_only=True)
     raw_tsss = maxwell_filter(raw_tsss)
@@ -771,7 +768,7 @@ def test_fine_calibration():
     log = log.getvalue()
     assert "Using fine calibration" in log
     assert fine_cal_fname.stem in log
-    assert_meg_snr(raw_sss, sss_fine_cal, 82, 611)
+    assert_meg_snr(raw_sss, sss_fine_cal, 1.3, 180)  # similar to MaxFilter
     py_cal = raw_sss.info["proc_history"][0]["max_info"]["sss_cal"]
     assert py_cal is not None
     assert len(py_cal) > 0
@@ -812,15 +809,11 @@ def test_fine_calibration():
         regularize=None,
         bad_condition="ignore",
     )
-    assert_meg_snr(raw_sss_3D, sss_fine_cal, 1.0, 6.0)
+    assert_meg_snr(raw_sss_3D, sss_fine_cal, 0.9, 6.0)
+    assert_meg_snr(raw_sss_3D, raw_sss, 1.1, 6.0)  # slightly better than 1D
     raw_ctf = read_crop(fname_ctf_raw).apply_gradient_compensation(0)
-    pytest.raises(
-        RuntimeError,
-        maxwell_filter,
-        raw_ctf,
-        origin=(0.0, 0.0, 0.04),
-        calibration=fine_cal_fname,
-    )
+    with pytest.raises(RuntimeError, match="Not all MEG channels"):
+        maxwell_filter(raw_ctf, origin=(0.0, 0.0, 0.04), calibration=fine_cal_fname)
 
 
 @pytest.mark.slowtest
@@ -884,7 +877,8 @@ def test_cross_talk(tmp_path):
     assert len(py_ctc) > 0
     with pytest.raises(TypeError, match="path-like"):
         maxwell_filter(raw, cross_talk=raw)
-    pytest.raises(ValueError, maxwell_filter, raw, cross_talk=raw_fname)
+    with pytest.raises(ValueError, match="Invalid cross-talk FIF"):
+        maxwell_filter(raw, cross_talk=raw_fname)
     mf_ctc = sss_ctc.info["proc_history"][0]["max_info"]["sss_ctc"]
     del mf_ctc["block_id"]  # we don't write this
     assert isinstance(py_ctc["decoupler"], sparse.csc_matrix)
@@ -916,13 +910,8 @@ def test_cross_talk(tmp_path):
     with pytest.warns(RuntimeWarning, match="Not all cross-talk channels"):
         maxwell_filter(raw_missing, cross_talk=ctc_fname)
     # MEG channels not in cross-talk
-    pytest.raises(
-        RuntimeError,
-        maxwell_filter,
-        raw_ctf,
-        origin=(0.0, 0.0, 0.04),
-        cross_talk=ctc_fname,
-    )
+    with pytest.raises(RuntimeError, match="Missing MEG channels"):
+        maxwell_filter(raw_ctf, origin=(0.0, 0.0, 0.04), cross_talk=ctc_fname)
 
 
 @testing.requires_testing_data
@@ -970,10 +959,10 @@ def test_head_translation():
         read_info(sample_fname)["dev_head_t"]["trans"],
     )
     # Degenerate cases
-    pytest.raises(
-        RuntimeError, maxwell_filter, raw, destination=mf_head_origin, coord_frame="meg"
-    )
-    pytest.raises(ValueError, maxwell_filter, raw, destination=[0.0] * 4)
+    with pytest.raises(RuntimeError, match=".* can only be set .* head .*"):
+        maxwell_filter(raw, destination=mf_head_origin, coord_frame="meg")
+    with pytest.raises(ValueError, match="destination must be"):
+        maxwell_filter(raw, destination=[0.0] * 4)
 
 
 # TODO: Eventually add simulation tests mirroring Taulu's original paper
@@ -994,7 +983,7 @@ def _assert_shielding(raw_sss, erm_power, min_factor, max_factor=np.inf, meg="ma
     factor = erm_power / sss_power
     assert (
         min_factor <= factor < max_factor
-    ), "Shielding factor not %0.3f <= %0.3f < %0.3f" % (min_factor, factor, max_factor)
+    ), f"Shielding factor not {min_factor:0.3f} <= {factor:0.3f} < {max_factor:0.3f}"
 
 
 @buggy_mkl_svd
@@ -1347,7 +1336,7 @@ def test_shielding_factor(tmp_path):
     assert counts[0] == 3
     # Show it by rewriting the 3D as 1D and testing it
     temp_fname = tmp_path / "test_cal.dat"
-    with open(fine_cal_fname_3d, "r") as fid:
+    with open(fine_cal_fname_3d) as fid:
         with open(temp_fname, "w") as fid_out:
             for line in fid:
                 fid_out.write(" ".join(line.strip().split(" ")[:14]) + "\n")
@@ -1395,7 +1384,7 @@ def test_all():
     coord_frames = ("head", "head", "meg", "head")
     ctcs = (ctc_fname, ctc_fname, ctc_fname, ctc_mgh_fname)
     mins = (3.5, 3.5, 1.2, 0.9)
-    meds = (10.8, 10.4, 3.2, 6.0)
+    meds = (10.8, 10.2, 3.2, 5.9)
     st_durs = (1.0, 1.0, 1.0, None)
     destinations = (None, sample_fname, None, None)
     origins = (mf_head_origin, mf_head_origin, mf_meg_origin, mf_head_origin)
@@ -1436,7 +1425,7 @@ def test_triux():
     sss_py = maxwell_filter(
         raw, coord_frame="meg", regularize=None, calibration=tri_cal_fname
     )
-    assert_meg_snr(sss_py, read_crop(tri_sss_cal_fname), 22, 200)
+    assert_meg_snr(sss_py, read_crop(tri_sss_cal_fname), 5, 100)
     # ctc+cal
     sss_py = maxwell_filter(
         raw,
@@ -1445,7 +1434,7 @@ def test_triux():
         calibration=tri_cal_fname,
         cross_talk=tri_ctc_fname,
     )
-    assert_meg_snr(sss_py, read_crop(tri_sss_ctc_cal_fname), 28, 200)
+    assert_meg_snr(sss_py, read_crop(tri_sss_ctc_cal_fname), 5, 100)
     # regularization
     sss_py = maxwell_filter(raw, coord_frame="meg", regularize="in")
     sss_mf = read_crop(tri_sss_reg_fname)
