@@ -14,7 +14,7 @@ from mne.event import read_events
 from mne.io import read_raw_fif
 from mne.preprocessing.stim import fix_stim_artifact
 
-data_path = Path(__file__).parent.parent.parent / "io" / "tests" / "data"
+data_path = Path(__file__).parents[2] / "io" / "tests" / "data"
 raw_fname = data_path / "test_raw.fif"
 event_fname = data_path / "test-eve.fif"
 
