@@ -66,7 +66,7 @@ fname_morph = subjects_dir / "sample" / "bem" / "sample-fsaverage-ico-5-src.fif"
 fname_src = data_path / "subjects" / "sample" / "bem" / "sample-oct-4-src.fif"
 fname_fwd = data_path / "MEG" / "sample" / "sample_audvis_trunc-meg-eeg-oct-4-fwd.fif"
 trans_fname = data_path / "MEG" / "sample" / "sample_audvis_trunc-trans.fif"
-base_dir = Path(__file__).parent.parent.parent / "io" / "tests" / "data"
+base_dir = Path(__file__).parents[2] / "io" / "tests" / "data"
 fname_small = base_dir / "small-src.fif.gz"
 fname_ave = base_dir / "test-ave.fif"
 rng = np.random.RandomState(0)
@@ -679,6 +679,7 @@ def test_source_space_from_label(tmp_path, pass_ids):
     _compare_source_spaces(src, src_from_file, mode="approx")
 
 
+@pytest.mark.slowtest
 @testing.requires_testing_data
 def test_source_space_exclusive_complete(src_volume_labels):
     """Test that we produce exclusive and complete labels."""
@@ -699,7 +700,10 @@ def test_source_space_exclusive_complete(src_volume_labels):
     for si, s in enumerate(src):
         assert_allclose(src_full[0]["rr"], s["rr"], atol=1e-6)
     # also check single_volume=True -- should be the same result
-    with pytest.warns(RuntimeWarning, match="Found no usable.*Left-vessel.*"):
+    with (
+        _record_warnings(),
+        pytest.warns(RuntimeWarning, match="Found no usable.*Left-vessel.*"),
+    ):
         src_single = setup_volume_source_space(
             src[0]["subject_his_id"],
             7.0,
@@ -870,6 +874,27 @@ def test_combine_source_spaces(tmp_path):
     with pytest.warns(RuntimeWarning, match="2 surf vertices lay outside"):
         src.export_volume(image_fname, mri_resolution="sparse", overwrite=True)
 
+    # gh-12495
+    image_fname = tmp_path / "temp-image.nii"
+    lh_cereb = mne.setup_volume_source_space(
+        "sample",
+        mri=aseg_fname,
+        volume_label="Left-Cerebellum-Cortex",
+        add_interpolator=False,
+        subjects_dir=subjects_dir,
+    )
+    lh_cereb.export_volume(image_fname, mri_resolution=True)
+    aseg = nib.load(str(aseg_fname))
+    out = nib.load(str(image_fname))
+    assert_allclose(out.affine, aseg.affine)
+    src_data = _get_img_fdata(out).astype(bool)
+    aseg_data = _get_img_fdata(aseg) == 8
+    n_src = src_data.sum()
+    n_aseg = aseg_data.sum()
+    assert n_aseg == n_src
+    n_overlap = (src_data & aseg_data).sum()
+    assert n_src == n_overlap
+
 
 @testing.requires_testing_data
 def test_morph_source_spaces():
