@@ -419,8 +419,8 @@ def _find_clusters(
         if show_info is True:
             if len(thresholds) == 0:
                 warn(
-                    'threshold["start"] (%s) is more extreme than data '
-                    "statistics with most extreme value %s" % (threshold["start"], stop)
+                    f'threshold["start"] ({threshold["start"]}) is more extreme '
+                    f"than data statistics with most extreme value {stop}"
                 )
             else:
                 logger.info(
@@ -479,7 +479,7 @@ def _find_clusters(
                     len_c = c.stop - c.start
                 elif isinstance(c, tuple):
                     len_c = len(c)
-                elif c.dtype == bool:
+                elif c.dtype == np.dtype(bool):
                     len_c = np.sum(c)
                 else:
                     len_c = len(c)
@@ -928,8 +928,7 @@ def _permutation_cluster_test(
             and threshold < 0
         ):
             raise ValueError(
-                "incompatible tail and threshold signs, got "
-                "%s and %s" % (tail, threshold)
+                f"incompatible tail and threshold signs, got {tail} and {threshold}"
             )
 
     # check dimensions for each group in X (a list at this stage).
@@ -956,7 +955,7 @@ def _permutation_cluster_test(
     # -------------------------------------------------------------
     t_obs = stat_fun(*X)
     _validate_type(t_obs, np.ndarray, "return value of stat_fun")
-    logger.info("stat_fun(H1): min=%f max=%f" % (np.min(t_obs), np.max(t_obs)))
+    logger.info(f"stat_fun(H1): min={np.min(t_obs)} max={np.max(t_obs)}")
 
     # test if stat_fun treats variables independently
     if buffer_size is not None:
@@ -976,9 +975,8 @@ def _permutation_cluster_test(
     # The stat should have the same shape as the samples for no adj.
     if t_obs.size != np.prod(sample_shape):
         raise ValueError(
-            "t_obs.shape %s provided by stat_fun %s is not "
-            "compatible with the sample shape %s"
-            % (t_obs.shape, stat_fun, sample_shape)
+            f"t_obs.shape {t_obs.shape} provided by stat_fun {stat_fun} is not "
+            f"compatible with the sample shape {sample_shape}"
         )
     if adjacency is None or adjacency is False:
         t_obs.shape = sample_shape
@@ -1138,14 +1136,14 @@ def _check_fun(X, stat_fun, threshold, tail=0, kind="within"):
             if stat_fun is not None and stat_fun is not ttest_1samp_no_p:
                 warn(
                     "Automatic threshold is only valid for stat_fun=None "
-                    "(or ttest_1samp_no_p), got %s" % (stat_fun,)
+                    f"(or ttest_1samp_no_p), got {stat_fun}"
                 )
             p_thresh = 0.05 / (1 + (tail == 0))
             n_samples = len(X)
             threshold = -tstat.ppf(p_thresh, n_samples - 1)
             if np.sign(tail) < 0:
                 threshold = -threshold
-            logger.info("Using a threshold of {:.6f}".format(threshold))
+            logger.info(f"Using a threshold of {threshold:.6f}")
         stat_fun = ttest_1samp_no_p if stat_fun is None else stat_fun
     else:
         assert kind == "between"
@@ -1153,7 +1151,7 @@ def _check_fun(X, stat_fun, threshold, tail=0, kind="within"):
             if stat_fun is not None and stat_fun is not f_oneway:
                 warn(
                     "Automatic threshold is only valid for stat_fun=None "
-                    "(or f_oneway), got %s" % (stat_fun,)
+                    f"(or f_oneway), got {stat_fun}"
                 )
             elif tail != 1:
                 warn('Ignoring argument "tail", performing 1-tailed F-test')
@@ -1161,7 +1159,7 @@ def _check_fun(X, stat_fun, threshold, tail=0, kind="within"):
             dfn = len(X) - 1
             dfd = np.sum([len(x) for x in X]) - len(X)
             threshold = fstat.ppf(1.0 - p_thresh, dfn, dfd)
-            logger.info("Using a threshold of {:.6f}".format(threshold))
+            logger.info(f"Using a threshold of {threshold:.6f}")
         stat_fun = f_oneway if stat_fun is None else stat_fun
     return stat_fun, threshold
 
@@ -1634,7 +1632,7 @@ def _reshape_clusters(clusters, sample_shape):
     """Reshape cluster masks or indices to be of the correct shape."""
     # format of the bool mask and indices are ndarrays
     if len(clusters) > 0 and isinstance(clusters[0], np.ndarray):
-        if clusters[0].dtype == bool:  # format of mask
+        if clusters[0].dtype == np.dtype(bool):  # format of mask
             clusters = [c.reshape(sample_shape) for c in clusters]
         else:  # format of indices
             clusters = [np.unravel_index(c, sample_shape) for c in clusters]
