@@ -64,7 +64,7 @@ fwd_fname = data_path / "MEG" / "sample" / "sample_audvis_trunc-meg-eeg-oct-6-fw
 src_bad_fname = data_path / "subjects" / "fsaverage" / "bem" / "fsaverage-ico-5-src.fif"
 label_dir = subjects_dir / "sample" / "label" / "aparc"
 
-test_path = Path(__file__).parent.parent / "io" / "tests" / "data"
+test_path = Path(__file__).parents[1] / "io" / "tests" / "data"
 label_fname = test_path / "test-lh.label"
 label_rh_fname = test_path / "test-rh.label"
 
@@ -182,7 +182,7 @@ def assert_labels_equal(l0, l1, decimal=5, comment=True, color=True):
     for attr in ["hemi", "subject"]:
         attr0 = getattr(l0, attr)
         attr1 = getattr(l1, attr)
-        msg = "label.%s: %r != %r" % (attr, attr0, attr1)
+        msg = f"label.{attr}: {repr(attr0)} != {repr(attr1)}"
         assert_equal(attr0, attr1, msg)
     for attr in ["vertices", "pos", "values"]:
         a0 = getattr(l0, attr)
