@@ -1,7 +1,4 @@
 """Container classes for spectral data."""
-
-# Authors: Dan McCloy <dan@mccloy.info>
-#
 # License: BSD-3-Clause
 # Copyright the MNE-Python contributors.
 
@@ -25,6 +22,7 @@ from ..html_templates import _get_html_template
 from ..utils import (
     GetEpochsMixin,
     _build_data_frame,
+    _check_method_kwargs,
     _check_pandas_index_arguments,
     _check_pandas_installed,
     _check_sphere,
@@ -45,13 +43,14 @@ from ..utils.check import (
     _is_numeric,
     check_fname,
 )
-from ..utils.misc import _pl
-from ..utils.spectrum import _split_psd_kwargs
+from ..utils.misc import _identity_function, _pl
+from ..utils.spectrum import _get_instance_type_string, _split_psd_kwargs
 from ..viz.topo import _plot_timeseries, _plot_timeseries_unified, _plot_topo
 from ..viz.topomap import _make_head_outlines, _prepare_topomap_plot, plot_psds_topomap
 from ..viz.utils import (
     _format_units_psd,
     _get_plot_ch_type,
+    _make_combine_callable,
     _plot_psd,
     _prepare_sensor_names,
     plt_show,
@@ -60,10 +59,6 @@ from .multitaper import psd_array_multitaper
 from .psd import _check_nfft, psd_array_welch
 
 
-def _identity_function(x):
-    return x
-
-
 class SpectrumMixin:
     """Mixin providing spectral plotting methods to sensor-space containers."""
 
@@ -318,29 +313,18 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
             )
         # method
         self._inst_type = type(inst)
-        method = _validate_method(method, self._get_instance_type_string())
+        method = _validate_method(method, _get_instance_type_string(self))
         # don't allow complex output
         psd_funcs = dict(welch=psd_array_welch, multitaper=psd_array_multitaper)
         if method_kw.get("output", "") == "complex":
-            warn(
-                f"Complex output support in {type(self).__name__} objects is "
-                "deprecated and will be removed in version 1.7. If you need complex "
-                f"output please use mne.time_frequency.{psd_funcs[method].__name__}() "
-                "instead.",
-                FutureWarning,
+            raise ValueError(
+                f"Complex output is not supported in {type(self).__name__} objects. "
+                f"Please use mne.time_frequency.{psd_funcs[method].__name__}() instead."
             )
         # triage method and kwargs. partial() doesn't check validity of kwargs,
         # so we do it manually to save compute time if any are invalid.
-        invalid_ix = np.isin(
-            list(method_kw), list(signature(psd_funcs[method]).parameters), invert=True
-        )
-        if invalid_ix.any():
-            invalid_kw = np.array(list(method_kw))[invalid_ix].tolist()
-            s = _pl(invalid_kw)
-            raise TypeError(
-                f'Got unexpected keyword argument{s} {", ".join(invalid_kw)} '
-                f'for PSD method "{method}".'
-            )
+        psd_funcs = dict(welch=psd_array_welch, multitaper=psd_array_multitaper)
+        _check_method_kwargs(psd_funcs[method], method_kw, msg=f'PSD method "{method}"')
         self._psd_func = partial(psd_funcs[method], remove_dc=remove_dc, **method_kw)
 
         # apply proj if desired
@@ -359,7 +343,7 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
         self.info = pick_info(inst.info, sel=self._picks, copy=True)
 
         # assign some attributes
-        self.preload = True  # needed for __getitem__, doesn't mean anything
+        self.preload = True  # needed for __getitem__, never False
         self._method = method
         # self._dims may also get updated by child classes
         self._dims = (
@@ -368,12 +352,12 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
         )
         if method_kw.get("average", "") in (None, False):
             self._dims += ("segment",)
-        if self._returns_complex_tapers(**method_kw):
-            self._dims = self._dims[:-1] + ("taper",) + self._dims[-1:]
         # record data type (for repr and html_repr)
         self._data_type = (
             "Fourier Coefficients" if "taper" in self._dims else "Power Spectrum"
         )
+        # set nave (child constructor overrides this for Evoked input)
+        self._nave = None
 
     def __eq__(self, other):
         """Test equivalence of two Spectrum instances."""
@@ -381,7 +365,7 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
 
     def __getstate__(self):
         """Prepare object for serialization."""
-        inst_type_str = self._get_instance_type_string()
+        inst_type_str = _get_instance_type_string(self)
         out = dict(
             method=self.method,
             data=self._data,
@@ -391,6 +375,7 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
             inst_type_str=inst_type_str,
             data_type=self._data_type,
             info=self.info,
+            nave=self.nave,
         )
         return out
 
@@ -407,16 +392,15 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
         self._sfreq = state["sfreq"]
         self.info = Info(**state["info"])
         self._data_type = state["data_type"]
+        self._nave = state.get("nave")  # objs saved before #11282 won't have `nave`
         self.preload = True
         # instance type
         inst_types = dict(Raw=Raw, Epochs=Epochs, Evoked=Evoked, Array=np.ndarray)
         self._inst_type = inst_types[state["inst_type_str"]]
-        if "weights" in state and state["weights"] is not None:
-            self._mt_weights = state["weights"]
 
     def __repr__(self):
         """Build string representation of the Spectrum object."""
-        inst_type_str = self._get_instance_type_string()
+        inst_type_str = _get_instance_type_string(self)
         # shape & dimension names
         dims = " × ".join(
             [f"{dim[0]} {dim[1]}s" for dim in zip(self.shape, self._dims)]
@@ -430,7 +414,7 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
     @repr_html
     def _repr_html_(self, caption=None):
         """Build HTML representation of the Spectrum object."""
-        inst_type_str = self._get_instance_type_string()
+        inst_type_str = _get_instance_type_string(self)
         units = [f"{ch_type}: {unit}" for ch_type, unit in self.units().items()]
         t = _get_html_template("repr", "spectrum.html.jinja")
         t = t.render(spectrum=self, inst_type=inst_type_str, units=units)
@@ -456,23 +440,14 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
             s = _pl(bad_value.sum())
             warn(f'Zero value in spectrum for channel{s} {", ".join(chs)}', UserWarning)
 
-    def _returns_complex_tapers(self, **method_kw):
-        return method_kw.get("output", "") == "complex" and self.method == "multitaper"
-
     def _compute_spectra(self, data, fmin, fmax, n_jobs, method_kw, verbose):
         # make the spectra
         result = self._psd_func(
             data, self.sfreq, fmin=fmin, fmax=fmax, n_jobs=n_jobs, verbose=verbose
         )
-        # assign ._data (handling unaggregated multitaper output)
-        if self._returns_complex_tapers(**method_kw):
-            fourier_coefs, freqs, weights = result
-            self._data = fourier_coefs
-            self._mt_weights = weights
-        else:
-            psds, freqs = result
-            self._data = psds
-        # assign properties (._data already assigned above)
+        # assign ._data ._freqs, ._shape
+        psds, freqs = result
+        self._data = psds
         self._freqs = freqs
         # this is *expected* shape, it gets asserted later in _check_values()
         # (and then deleted afterwards)
@@ -481,33 +456,11 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
         if method_kw.get("average", "") in (None, False):
             n_welch_segments = _compute_n_welch_segments(data.shape[-1], method_kw)
             self._shape += (n_welch_segments,)
-        # insert n_tapers
-        if self._returns_complex_tapers(**method_kw):
-            self._shape = self._shape[:-1] + (self._mt_weights.size,) + self._shape[-1:]
         # we don't need these anymore, and they make save/load harder
         del self._picks
         del self._psd_func
         del self._time_mask
 
-    def _get_instance_type_string(self):
-        """Get string representation of the originating instance type."""
-        from ..epochs import BaseEpochs
-        from ..evoked import Evoked, EvokedArray
-        from ..io import BaseRaw
-
-        parent_classes = self._inst_type.__bases__
-        if BaseRaw in parent_classes:
-            inst_type_str = "Raw"
-        elif BaseEpochs in parent_classes:
-            inst_type_str = "Epochs"
-        elif self._inst_type in (Evoked, EvokedArray):
-            inst_type_str = "Evoked"
-        elif self._inst_type is np.ndarray:
-            inst_type_str = "Array"
-        else:
-            raise RuntimeError(f"Unknown instance type {self._inst_type} in Spectrum")
-        return inst_type_str
-
     @property
     def _detrend_picks(self):
         """Provide compatibility with __iter__."""
@@ -517,6 +470,10 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
     def ch_names(self):
         return self.info["ch_names"]
 
+    @property
+    def data(self):
+        return self._data
+
     @property
     def freqs(self):
         return self._freqs
@@ -525,6 +482,10 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
     def method(self):
         return self._method
 
+    @property
+    def nave(self):
+        return self._nave
+
     @property
     def sfreq(self):
         return self._sfreq
@@ -592,7 +553,7 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
         picks=None,
         average=False,
         dB=True,
-        amplitude="auto",
+        amplitude=None,
         xscale="linear",
         ci="sd",
         ci_alpha=0.3,
@@ -612,57 +573,56 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
 
             .. versionchanged:: 1.5
                 In version 1.5, the default behavior changed so that all
-                :term:`data channels` (not just "good" data channels) are shown
-                by default.
+                :term:`data channels` (not just "good" data channels) are shown by
+                default.
         average : bool
-            Whether to average across channels before plotting. If ``True``,
-            interactive plotting of scalp topography is disabled, and
-            parameters ``ci`` and ``ci_alpha`` control the style of the
-            confidence band around the mean. Default is ``False``.
+            Whether to average across channels before plotting. If ``True``, interactive
+            plotting of scalp topography is disabled, and parameters ``ci`` and
+            ``ci_alpha`` control the style of the confidence band around the mean.
+            Default is ``False``.
         %(dB_spectrum_plot)s
         amplitude : bool | 'auto'
             Whether to plot an amplitude spectrum (``True``) or power spectrum
-            (``False``). If ``'auto'``, will plot a power spectrum when
-            ``dB=True`` and an amplitude spectrum otherwise. Default is
-            ``'auto'``.
+            (``False``). If ``'auto'``, will plot a power spectrum when ``dB=True`` and
+            an amplitude spectrum otherwise. Default is ``'auto'``.
+
+                .. versionchanged:: 1.8
+                    In version 1.8, the value ``amplitude="auto"`` will be removed. The
+                    default value will change to ``amplitude=False``.
         %(xscale_plot_psd)s
         ci : float | 'sd' | 'range' | None
-            Type of confidence band drawn around the mean when
-            ``average=True``. If ``'sd'`` the band spans ±1 standard deviation
-            across channels. If ``'range'`` the band spans the range across
-            channels at each frequency. If a :class:`float`, it indicates the
-            (bootstrapped) confidence interval to display, and must satisfy
-            ``0 < ci <= 100``. If ``None``, no band is drawn. Default is
-            ``sd``.
+            Type of confidence band drawn around the mean when ``average=True``. If
+            ``'sd'`` the band spans ±1 standard deviation across channels. If
+            ``'range'`` the band spans the range across channels at each frequency. If a
+            :class:`float`, it indicates the (bootstrapped) confidence interval to
+            display, and must satisfy ``0 < ci <= 100``. If ``None``, no band is drawn.
+            Default is ``sd``.
         ci_alpha : float
-            Opacity of the confidence band. Must satisfy
-            ``0 <= ci_alpha <= 1``. Default is 0.3.
+            Opacity of the confidence band. Must satisfy ``0 <= ci_alpha <= 1``. Default
+            is 0.3.
         %(color_plot_psd)s
         alpha : float | None
             Opacity of the spectrum line(s). If :class:`float`, must satisfy
             ``0 <= alpha <= 1``. If ``None``, opacity will be ``1`` when
-            ``average=True`` and ``0.1`` when ``average=False``. Default is
-            ``None``.
+            ``average=True`` and ``0.1`` when ``average=False``. Default is ``None``.
         %(spatial_colors_psd)s
         %(sphere_topomap_auto)s
         %(exclude_spectrum_plot)s
 
             .. versionchanged:: 1.5
-                In version 1.5, the default behavior changed from
-                ``exclude='bads'`` to ``exclude=()``.
+                In version 1.5, the default behavior changed from ``exclude='bads'`` to
+                ``exclude=()``.
         %(axes_spectrum_plot_topomap)s
         %(show)s
 
         Returns
         -------
         fig : instance of matplotlib.figure.Figure
-            Figure with spectra plotted in separate subplots for each channel
-            type.
+            Figure with spectra plotted in separate subplots for each channel type.
         """
         # Must nest this _mpl_figure import because of the BACKEND global
         # stuff
         from ..viz._mpl_figure import _line_figure, _split_picks_by_type
-        from .multitaper import _psd_from_mt
 
         # arg checking
         ci = _check_ci(ci)
@@ -672,10 +632,19 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
         scalings = _handle_default("scalings", None)
         titles = _handle_default("titles", None)
         units = _handle_default("units", None)
-        if amplitude == "auto":
+
+        depr_message = (
+            "The value of `amplitude='auto'` will be removed in MNE 1.8.0, and the new "
+            "default will be `amplitude=False`."
+        )
+        if amplitude is None or amplitude == "auto":
+            warn(depr_message, FutureWarning)
             estimate = "power" if dB else "amplitude"
-        else:  # amplitude is boolean
+        else:
             estimate = "amplitude" if amplitude else "power"
+
+        logger.info(f"Plotting {estimate} spectral density ({dB=}).")
+
         # split picks by channel type
         picks = _picks_to_idx(
             self.info, picks, "data", exclude=exclude, with_ref_meg=False
@@ -683,12 +652,8 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
         (picks_list, units_list, scalings_list, titles_list) = _split_picks_by_type(
             self, picks, units, scalings, titles
         )
-        # handle unaggregated multitaper
-        if hasattr(self, "_mt_weights"):
-            logger.info("Aggregating multitaper estimates before plotting...")
-            _f = partial(_psd_from_mt, weights=self._mt_weights)
         # handle unaggregated Welch
-        elif "segment" in self._dims:
+        if "segment" in self._dims:
             logger.info("Aggregating Welch estimates (median) before plotting...")
             seg_axis = self._dims.index("segment")
             _f = partial(np.nanmedian, axis=seg_axis)
@@ -996,7 +961,7 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
         # check pandas once here, instead of in each private utils function
         pd = _check_pandas_installed()  # noqa
         # triage for Epoch-derived or unaggregated spectra
-        from_epo = self._dims[0] == "epoch"
+        from_epo = _get_instance_type_string(self) == "Epochs"
         unagg_welch = "segment" in self._dims
         unagg_mt = "taper" in self._dims
         # arg checking
@@ -1059,9 +1024,8 @@ class BaseSpectrum(ContainsMixin, UpdateChannelsMixin):
             for that channel type.
         """
         units = _handle_default("si_units", None)
-        power = not hasattr(self, "_mt_weights")
         return {
-            ch_type: _format_units_psd(units[ch_type], power=power, latex=latex)
+            ch_type: _format_units_psd(units[ch_type], power=True, latex=latex)
             for ch_type in sorted(self.get_channel_types(unique=True))
         }
 
@@ -1103,8 +1067,10 @@ class Spectrum(BaseSpectrum):
         have been computed.
     %(info_not_none)s
     method : str
-        The method used to compute the spectrum (``'welch'`` or
-        ``'multitaper'``).
+        The method used to compute the spectrum (``'welch'`` or ``'multitaper'``).
+    nave : int | None
+        The number of trials averaged together when generating the spectrum. ``None``
+        indicates no averaging is known to have occurred.
 
     See Also
     --------
@@ -1166,13 +1132,21 @@ class Spectrum(BaseSpectrum):
             data = self.inst.get_data(
                 self._picks, start, stop + 1, reject_by_annotation=rba
             )
+            if np.any(np.isnan(data)) and method == "multitaper":
+                raise NotImplementedError(
+                    'Cannot use method="multitaper" when reject_by_annotation=True. '
+                    'Please use method="welch" instead.'
+                )
+
         else:  # Evoked
             data = self.inst.data[self._picks][:, self._time_mask]
+        # set nave
+        self._nave = getattr(inst, "nave", None)
         # compute the spectra
         self._compute_spectra(data, fmin, fmax, n_jobs, method_kw, verbose)
         # check for correct shape and bad values
         self._check_values()
-        del self._shape
+        del self._shape  # calculated from self._data henceforth
         # save memory
         del self.inst
 
@@ -1205,7 +1179,8 @@ class Spectrum(BaseSpectrum):
            requested data values and the corresponding times), accessing
            :class:`~mne.time_frequency.Spectrum` values via subscript does
            **not** return the corresponding frequency bin values. If you need
-           them, use ``spectrum.freqs[freq_indices]``.
+           them, use ``spectrum.freqs[freq_indices]`` or
+           ``spectrum.get_data(..., return_freqs=True)``.
         """
         from ..io import BaseRaw
 
@@ -1240,7 +1215,7 @@ class SpectrumArray(Spectrum):
     data : array, shape (n_channels, n_freqs)
         The power spectral density for each channel.
     %(info_not_none)s
-    %(freqs_tfr)s
+    %(freqs_tfr_array)s
     %(verbose)s
 
     See Also
@@ -1438,21 +1413,17 @@ class EpochsSpectrum(BaseSpectrum, GetEpochsMixin):
         spectrum : instance of Spectrum
             The aggregated spectrum object.
         """
-        if isinstance(method, str):
-            method = getattr(np, method)  # mean, median, std, etc
-            method = partial(method, axis=0)
+        _validate_type(method, ("str", "callable"))
+        method = _make_combine_callable(
+            method, axis=0, valid=("mean", "median"), keepdims=False
+        )
         if not callable(method):
             raise ValueError(
                 '"method" must be a valid string or callable, '
                 f"got a {type(method).__name__} ({method})."
             )
         # averaging unaggregated spectral estimates are not supported
-        if hasattr(self, "_mt_weights"):
-            raise NotImplementedError(
-                "Averaging complex spectra is not supported. Consider "
-                "averaging the signals before computing the complex spectrum."
-            )
-        elif "segment" in self._dims:
+        if "segment" in self._dims:
             raise NotImplementedError(
                 "Averaging individual Welch segments across epochs is not "
                 "supported. Consider averaging the signals before computing "
@@ -1460,6 +1431,7 @@ class EpochsSpectrum(BaseSpectrum, GetEpochsMixin):
             )
         # serialize the object and update data, dims, and data type
         state = super().__getstate__()
+        state["nave"] = state["data"].shape[0]
         state["data"] = method(state["data"])
         state["dims"] = state["dims"][1:]
         state["data_type"] = f'Averaged {state["data_type"]}'
@@ -1489,7 +1461,7 @@ class EpochsSpectrumArray(EpochsSpectrum):
     data : array, shape (n_epochs, n_channels, n_freqs)
         The power spectral density for each channel in each epoch.
     %(info_not_none)s
-    %(freqs_tfr)s
+    %(freqs_tfr_array)s
     %(events_epochs)s
     %(event_id)s
     %(verbose)s
