@@ -50,7 +50,7 @@ class _TempDir(str):
         new = str.__new__(self, tempfile.mkdtemp(prefix="tmp_mne_tempdir_"))
         return new
 
-    def __init__(self):  # noqa: D102
+    def __init__(self):
         self._path = self.__str__()
 
     def __del__(self):  # noqa: D105
@@ -121,7 +121,7 @@ def run_command_if_main():
 class ArgvSetter:
     """Temporarily set sys.argv."""
 
-    def __init__(self, args=(), disable_stdout=True, disable_stderr=True):  # noqa: D102
+    def __init__(self, args=(), disable_stdout=True, disable_stderr=True):
         self.argv = list(("python",) + args)
         self.stdout = ClosingStringIO() if disable_stdout else sys.stdout
         self.stderr = ClosingStringIO() if disable_stderr else sys.stderr
@@ -243,16 +243,13 @@ def _check_snr(actual, desired, picks, min_tol, med_tol, msg, kind="MEG"):
     snr = snrs.min()
     bad_count = (snrs < min_tol).sum()
     msg = " (%s)" % msg if msg != "" else msg
-    assert bad_count == 0, "SNR (worst %0.2f) < %0.2f for %s/%s " "channels%s" % (
-        snr,
-        min_tol,
-        bad_count,
-        len(picks),
-        msg,
+    assert bad_count == 0, (
+        f"SNR (worst {snr:0.2f}) < {min_tol:0.2f} "
+        f"for {bad_count}/{len(picks)} channels{msg}"
     )
     # median tol
     snr = np.median(snrs)
-    assert snr >= med_tol, "%s SNR median %0.2f < %0.2f%s" % (kind, snr, med_tol, msg)
+    assert snr >= med_tol, f"{kind} SNR median {snr:0.2f} < {med_tol:0.2f}{msg}"
 
 
 def assert_meg_snr(
@@ -296,7 +293,7 @@ def assert_snr(actual, desired, tol):
     """Assert actual and desired arrays are within some SNR tolerance."""
     with np.errstate(divide="ignore"):  # allow infinite
         snr = linalg.norm(desired, ord="fro") / linalg.norm(desired - actual, ord="fro")
-    assert snr >= tol, "%f < %f" % (snr, tol)
+    assert snr >= tol, f"{snr} < {tol}"
 
 
 def assert_stcs_equal(stc1, stc2):
@@ -344,7 +341,7 @@ def assert_dig_allclose(info_py, info_bin, limit=None):
             d_bin["r"],
             rtol=1e-5,
             atol=1e-5,
-            err_msg="Failure on %s:\n%s\n%s" % (ii, d_py["r"], d_bin["r"]),
+            err_msg=f"Failure on {ii}:\n{d_py['r']}\n{d_bin['r']}",
         )
     if any(d["kind"] == FIFF.FIFFV_POINT_EXTRA for d in dig_py) and info_py is not None:
         r_bin, o_head_bin, o_dev_bin = fit_sphere_to_headshape(
@@ -368,3 +365,13 @@ def _click_ch_name(fig, ch_index=0, button=1):
     x = bbox.intervalx.mean()
     y = bbox.intervaly.mean()
     _fake_click(fig, fig.mne.ax_main, (x, y), xform="pix", button=button)
+
+
+def _get_suptitle(fig):
+    """Get fig suptitle (shim for matplotlib < 3.8.0)."""
+    # TODO: obsolete when minimum MPL version is 3.8
+    if check_version("matplotlib", "3.8"):
+        return fig.get_suptitle()
+    else:
+        # unreliable hack; should work in most tests as we rarely use `sup_{x,y}label`
+        return fig.texts[0].get_text()
