@@ -10,7 +10,6 @@ import multiprocessing
 import os
 import os.path as op
 import platform
-import re
 import shutil
 import subprocess
 import sys
@@ -218,7 +217,7 @@ _known_config_wildcards = (
 
 def _load_config(config_path, raise_error=False):
     """Safely load a config file."""
-    with open(config_path, "r") as fid:
+    with open(config_path) as fid:
         try:
             config = json.load(fid)
         except ValueError:
@@ -329,9 +328,9 @@ def get_config(key=None, default=None, raise_error=False, home_dir=None, use_env
             "for a permanent one" % key
         )
         raise KeyError(
-            'Key "%s" not found in %s'
-            "the mne-python config file (%s). "
-            "Try %s%s.%s" % (key, loc_env, config_path, meth_env, meth_file, extra_env)
+            f'Key "{key}" not found in {loc_env}'
+            f"the mne-python config file ({config_path}). "
+            f"Try {meth_env}{meth_file}.{extra_env}"
         )
     else:
         return config.get(key, default)
@@ -626,16 +625,6 @@ def sys_info(
     _validate_type(check_version, (bool, "numeric"), "check_version")
     ljust = 24 if dependencies == "developer" else 21
     platform_str = platform.platform()
-    if platform.system() == "Darwin" and sys.version_info[:2] < (3, 8):
-        # platform.platform() in Python < 3.8 doesn't call
-        # platform.mac_ver() if we're on Darwin, so we don't get a nice macOS
-        # version number. Therefore, let's do this manually here.
-        macos_ver = platform.mac_ver()[0]
-        macos_architecture = re.findall("Darwin-.*?-(.*)", platform_str)
-        if macos_architecture:
-            macos_architecture = macos_architecture[0]
-            platform_str = f"macOS-{macos_ver}-{macos_architecture}"
-        del macos_ver, macos_architecture
 
     out = partial(print, end="", file=fid)
     out("Platform".ljust(ljust) + platform_str + "\n")
@@ -660,8 +649,6 @@ def sys_info(
         "numpy",
         "scipy",
         "matplotlib",
-        "pooch",
-        "jinja2",
         "",
         "# Numerical (optional)",
         "sklearn",
@@ -672,6 +659,8 @@ def sys_info(
         "openmeeg",
         "cupy",
         "pandas",
+        "h5io",
+        "h5py",
         "",
         "# Visualization (optional)",
         "pyvista",
@@ -695,6 +684,11 @@ def sys_info(
         "mne-connectivity",
         "mne-icalabel",
         "mne-bids-pipeline",
+        "neo",
+        "eeglabio",
+        "edfio",
+        "mffpy",
+        "pybv",
         "",
     )
     if dependencies == "developer":
@@ -702,15 +696,28 @@ def sys_info(
             "# Testing",
             "pytest",
             "nbclient",
+            "statsmodels",
             "numpydoc",
             "flake8",
             "pydocstyle",
+            "nitime",
+            "imageio",
+            "imageio-ffmpeg",
+            "snirf",
             "",
             "# Documentation",
             "sphinx",
             "sphinx-gallery",
             "pydata-sphinx-theme",
             "",
+            "# Infrastructure",
+            "decorator",
+            "jinja2",
+            # "lazy-loader",
+            "packaging",
+            "pooch",
+            "tqdm",
+            "",
         )
     try:
         unicode = unicode and (sys.stdout.encoding.lower().startswith("utf"))
