@@ -14,6 +14,7 @@ import sys
 import traceback
 import weakref
 from contextlib import ExitStack, contextmanager
+from importlib.resources import files
 from math import log
 from queue import Empty, Queue
 from string import Formatter
@@ -26,11 +27,9 @@ from decorator import FunctionMaker
 from ._logging import logger, verbose, warn
 from .check import _check_option, _validate_type
 
-# TODO: remove try/except when our min version is py 3.9
-try:
-    from importlib.resources import files
-except ImportError:
-    from importlib_resources import files
+
+def _identity_function(x):
+    return x
 
 
 # TODO: no longer needed when py3.9 is minimum supported version
@@ -161,20 +160,7 @@ def run_subprocess(command, return_code=False, verbose=None, *args, **kwargs):
                     break
                 else:
                     out = out.decode("utf-8")
-                    # Strip newline at end of the string, otherwise we'll end
-                    # up with two subsequent newlines (as the logger adds one)
-                    #
-                    # XXX Once we drop support for Python <3.9, uncomment the
-                    # following line and remove the if/else block below.
-                    #
-                    # log_out = out.removesuffix('\n')
-                    if sys.version_info[:2] >= (3, 9):
-                        log_out = out.removesuffix("\n")
-                    elif out.endswith("\n"):
-                        log_out = out[:-1]
-                    else:
-                        log_out = out
-
+                    log_out = out.removesuffix("\n")
                     logger.info(log_out)
                     all_out += out
 
@@ -185,19 +171,7 @@ def run_subprocess(command, return_code=False, verbose=None, *args, **kwargs):
                     break
                 else:
                     err = err.decode("utf-8")
-                    # Strip newline at end of the string, otherwise we'll end
-                    # up with two subsequent newlines (as the logger adds one)
-                    #
-                    # XXX Once we drop support for Python <3.9, uncomment the
-                    # following line and remove the if/else block below.
-                    #
-                    # err_out = err.removesuffix('\n')
-                    if sys.version_info[:2] >= (3, 9):
-                        err_out = err.removesuffix("\n")
-                    elif err.endswith("\n"):
-                        err_out = err[:-1]
-                    else:
-                        err_out = err
+                    err_out = err.removesuffix("\n")
 
                     # Leave this as logger.warning rather than warn(...) to
                     # mirror the logger.info above for stdout. This function
@@ -295,9 +269,8 @@ def running_subprocess(command, after="wait", verbose=None, *args, **kwargs):
 def _clean_names(names, remove_whitespace=False, before_dash=True):
     """Remove white-space on topo matching.
 
-    This function handles different naming
-    conventions for old VS new VectorView systems (`remove_whitespace`).
-    Also it allows to remove system specific parts in CTF channel names
+    This function handles different naming conventions for old VS new VectorView systems
+    (`remove_whitespace`) and removes system specific parts in CTF channel names
     (`before_dash`).
 
     Usage
@@ -307,7 +280,6 @@ def _clean_names(names, remove_whitespace=False, before_dash=True):
 
     # for CTF
     ch_names = _clean_names(epochs.ch_names, before_dash=True)
-
     """
     cleaned = []
     for name in names:
@@ -318,7 +290,10 @@ def _clean_names(names, remove_whitespace=False, before_dash=True):
         if name.endswith("_v"):
             name = name[:-2]
         cleaned.append(name)
-
+    if len(set(cleaned)) != len(names):
+        # this was probably not a VectorView or CTF dataset, and we now broke the
+        # dataset by creating duplicates, so let's use the original channel names.
+        return names
     return cleaned
 
 
