@@ -26,7 +26,7 @@ from mne.utils import (
 )
 from mne.utils._logging import _frame_info
 
-base_dir = Path(__file__).parent.parent.parent / "io" / "tests" / "data"
+base_dir = Path(__file__).parents[2] / "io" / "tests" / "data"
 fname_raw = base_dir / "test_raw.fif"
 fname_evoked = base_dir / "test-ave.fif"
 fname_log = base_dir / "test-ave.log"
@@ -63,7 +63,7 @@ def test_frame_info(capsys, monkeypatch):
 
 def test_how_to_deal_with_warnings():
     """Test filter some messages out of warning records."""
-    with pytest.warns(UserWarning, match="bb") as w:
+    with pytest.warns(Warning, match="(bb|aa) warning") as w:
         warnings.warn("aa warning", UserWarning)
         warnings.warn("bb warning", UserWarning)
         warnings.warn("bb warning", RuntimeWarning)
@@ -73,7 +73,7 @@ def test_how_to_deal_with_warnings():
     assert len(w) == 1
 
 
-def clean_lines(lines=[]):
+def clean_lines(lines=()):
     """Scrub filenames for checking logging output (in test_logging)."""
     return [line if "Reading " not in line else "Reading test file" for line in lines]
 
@@ -84,11 +84,11 @@ def test_logging_options(tmp_path):
         with pytest.raises(ValueError, match="Invalid value for the 'verbose"):
             set_log_level("foo")
         test_name = tmp_path / "test.log"
-        with open(fname_log, "r") as old_log_file:
+        with open(fname_log) as old_log_file:
             # [:-1] used to strip an extra "No baseline correction applied"
             old_lines = clean_lines(old_log_file.readlines())
             old_lines.pop(-1)
-        with open(fname_log_2, "r") as old_log_file_2:
+        with open(fname_log_2) as old_log_file_2:
             old_lines_2 = clean_lines(old_log_file_2.readlines())
             old_lines_2.pop(14)
             old_lines_2.pop(-1)
@@ -112,7 +112,7 @@ def test_logging_options(tmp_path):
             assert fid.readlines() == []
         # SHOULD print
         evoked = read_evokeds(fname_evoked, condition=1, verbose=True)
-        with open(test_name, "r") as new_log_file:
+        with open(test_name) as new_log_file:
             new_lines = clean_lines(new_log_file.readlines())
         assert new_lines == old_lines
         set_log_file(None)  # Need to do this to close the old file
@@ -131,7 +131,7 @@ def test_logging_options(tmp_path):
             assert fid.readlines() == []
         # SHOULD print
         evoked = read_evokeds(fname_evoked, condition=1)
-        with open(test_name, "r") as new_log_file:
+        with open(test_name) as new_log_file:
             new_lines = clean_lines(new_log_file.readlines())
         assert new_lines == old_lines
         # check to make sure appending works (and as default, raises a warning)
@@ -139,7 +139,7 @@ def test_logging_options(tmp_path):
         with pytest.warns(RuntimeWarning, match="appended to the file"):
             set_log_file(test_name)
         evoked = read_evokeds(fname_evoked, condition=1)
-        with open(test_name, "r") as new_log_file:
+        with open(test_name) as new_log_file:
             new_lines = clean_lines(new_log_file.readlines())
         assert new_lines == old_lines_2
 
@@ -148,7 +148,7 @@ def test_logging_options(tmp_path):
         # this line needs to be called to actually do some logging
         evoked = read_evokeds(fname_evoked, condition=1)
         del evoked
-        with open(test_name, "r") as new_log_file:
+        with open(test_name) as new_log_file:
             new_lines = clean_lines(new_log_file.readlines())
         assert new_lines == old_lines
     with catch_logging() as log:
