@@ -7,10 +7,11 @@
 #          jona-sassenhagen <jona.sassenhagen@gmail.com>
 #          Joan Massich <mailsik@gmail.com>
 #
-# License: Simplified BSD
+# License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 
 from ._brain import Brain, _LayeredMesh
 from ._scraper import _BrainScraper
 from ._linkviewer import _LinkViewer
 
-__all__ = ['Brain']
+__all__ = ["Brain"]
