@@ -166,11 +166,11 @@ class _AbstractRenderer(ABC):
             The scalar valued associated to the vertices.
         vmin : float | None
             vmin is used to scale the colormap.
-            If None, the min of the data will be used
+            If None, the min of the data will be used.
         vmax : float | None
             vmax is used to scale the colormap.
-            If None, the max of the data will be used
-        colormap :
+            If None, the max of the data will be used.
+        colormap : str | np.ndarray | matplotlib.colors.Colormap | None
             The colormap to use.
         interpolate_before_map :
             Enabling makes for a smoother scalars display. Default is True.
@@ -225,17 +225,17 @@ class _AbstractRenderer(ABC):
             The opacity of the contour.
         vmin : float | None
             vmin is used to scale the colormap.
-            If None, the min of the data will be used
+            If None, the min of the data will be used.
         vmax : float | None
             vmax is used to scale the colormap.
-            If None, the max of the data will be used
-        colormap :
+            If None, the max of the data will be used.
+        colormap : str | np.ndarray | matplotlib.colors.Colormap | None
             The colormap to use.
         normalized_colormap : bool
             Specify if the values of the colormap are between 0 and 1.
         kind : 'line' | 'tube'
             The type of the primitives to use to display the contours.
-        color :
+        color : tuple | str
             The color of the mesh as a tuple (red, green, blue) of float
             values between 0 and 1 or a valid color name (i.e. 'white'
             or 'w').
@@ -270,11 +270,11 @@ class _AbstractRenderer(ABC):
             The opacity of the surface.
         vmin : float | None
             vmin is used to scale the colormap.
-            If None, the min of the data will be used
+            If None, the min of the data will be used.
         vmax : float | None
             vmax is used to scale the colormap.
-            If None, the max of the data will be used
-        colormap :
+            If None, the max of the data will be used.
+        colormap : str | np.ndarray | matplotlib.colors.Colormap | None
             The colormap to use.
         scalars : ndarray, shape (n_vertices,)
             The scalar valued associated to the vertices.
@@ -354,11 +354,11 @@ class _AbstractRenderer(ABC):
             The optional scalar data to use.
         vmin : float | None
             vmin is used to scale the colormap.
-            If None, the min of the data will be used
+            If None, the min of the data will be used.
         vmax : float | None
             vmax is used to scale the colormap.
-            If None, the max of the data will be used
-        colormap :
+            If None, the max of the data will be used.
+        colormap : str | np.ndarray | matplotlib.colors.Colormap | None
             The colormap to use.
         opacity : float
             The opacity of the tube(s).
@@ -446,7 +446,7 @@ class _AbstractRenderer(ABC):
             The optional scalar data to use.
         backface_culling : bool
             If True, enable backface culling on the quiver.
-        colormap :
+        colormap : str | np.ndarray | matplotlib.colors.Colormap | None
             The colormap to use.
         vmin : float | None
             vmin is used to scale the colormap.
@@ -518,15 +518,15 @@ class _AbstractRenderer(ABC):
 
         Parameters
         ----------
-        source :
+        source
             The object of the scene used for the colormap.
-        color :
+        color : tuple | str
             The color of the label text.
         title : str | None
             The title of the scalar bar.
         n_labels : int | None
             The number of labels to display on the scalar bar.
-        bgcolor :
+        bgcolor : tuple | str
             The color of the background when there is transparency.
         """
         pass
@@ -549,8 +549,6 @@ class _AbstractRenderer(ABC):
         distance=None,
         focalpoint=None,
         roll=None,
-        *,
-        reset_camera=None,
     ):
         """Configure the camera of the scene.
 
@@ -566,16 +564,9 @@ class _AbstractRenderer(ABC):
             The focal point of the camera: (x, y, z).
         roll : float
             The rotation of the camera along its axis.
-        reset_camera : bool
-           Deprecated, used ``distance="auto"`` instead.
         """
         pass
 
-    @abstractclassmethod
-    def reset_camera(self):
-        """Reset the camera properties."""
-        pass
-
     @abstractclassmethod
     def screenshot(self, mode="rgb", filename=None):
         """Take a screenshot of the scene.
@@ -1145,7 +1136,7 @@ class _AbstractDock(ABC):
         desc,
         func,
         *,
-        filter=None,
+        filter_=None,
         initial_directory=None,
         save=False,
         is_directory=False,
@@ -1218,7 +1209,7 @@ class _AbstractDialog(ABC):
         callback,
         *,
         icon="Warning",
-        buttons=[],
+        buttons=(),
         modal=True,
         window=None,
     ):
