@@ -112,6 +112,7 @@ from ._pyvista import (
     _take_3d_screenshot,  # noqa: F401
 )
 from ._utils import (
+    _ICONS_PATH,
     _init_mne_qtapp,
     _qt_app_exec,
     _qt_detect_theme,
@@ -276,13 +277,13 @@ class _Button(QPushButton, _AbstractButton, _Widget, metaclass=_BaseWidget):
         self.setText(value)
         self.released.connect(callback)
         if icon:
-            self.setIcon(QIcon.fromTheme(icon))
+            self.setIcon(_qicon(icon))
 
     def _click(self):
         self.click()
 
     def _set_icon(self, icon):
-        self.setIcon(QIcon.fromTheme(icon))
+        self.setIcon(_qicon(icon))
 
 
 class _Slider(QSlider, _AbstractSlider, _Widget, metaclass=_BaseWidget):
@@ -474,16 +475,16 @@ class _PlayMenu(QVBoxLayout, _AbstractPlayMenu, _Widget, metaclass=_BaseWidget):
         self._slider.valueChanged.connect(callback)
         self._nav_hbox = QHBoxLayout()
         self._play_button = QPushButton()
-        self._play_button.setIcon(QIcon.fromTheme("play"))
+        self._play_button.setIcon(_qicon("play"))
         self._nav_hbox.addWidget(self._play_button)
         self._pause_button = QPushButton()
-        self._pause_button.setIcon(QIcon.fromTheme("pause"))
+        self._pause_button.setIcon(_qicon("pause"))
         self._nav_hbox.addWidget(self._pause_button)
         self._reset_button = QPushButton()
-        self._reset_button.setIcon(QIcon.fromTheme("reset"))
+        self._reset_button.setIcon(_qicon("reset"))
         self._nav_hbox.addWidget(self._reset_button)
         self._loop_button = QPushButton()
-        self._loop_button.setIcon(QIcon.fromTheme("restore"))
+        self._loop_button.setIcon(_qicon("restore"))
         self._loop_button.setStyleSheet("background-color : lightgray;")
         self._loop_button._checked = True
 
@@ -930,7 +931,7 @@ class _QtDialog(_AbstractDialog):
         callback,
         *,
         icon="Warning",
-        buttons=[],
+        buttons=(),
         modal=True,
         window=None,
     ):
@@ -1205,7 +1206,7 @@ class _QtDock(_AbstractDock, _QtLayout):
         desc,
         func,
         *,
-        filter=None,
+        filter_=None,
         initial_directory=None,
         save=False,
         is_directory=False,
@@ -1226,11 +1227,11 @@ class _QtDock(_AbstractDock, _QtLayout):
                 )
             elif save:
                 name = QFileDialog.getSaveFileName(
-                    parent=self._window, directory=initial_directory, filter=filter
+                    parent=self._window, directory=initial_directory, filter=filter_
                 )
             else:
                 name = QFileDialog.getOpenFileName(
-                    parent=self._window, directory=initial_directory, filter=filter
+                    parent=self._window, directory=initial_directory, filter=filter_
                 )
             name = name[0] if isinstance(name, tuple) else name
             # handle the cancel button
@@ -1494,18 +1495,18 @@ class _QtWindow(_AbstractWindow):
         self._window.closeEvent = closeEvent
 
     def _window_load_icons(self):
-        self._icons["help"] = QIcon.fromTheme("help")
-        self._icons["play"] = QIcon.fromTheme("play")
-        self._icons["pause"] = QIcon.fromTheme("pause")
-        self._icons["reset"] = QIcon.fromTheme("reset")
-        self._icons["scale"] = QIcon.fromTheme("scale")
-        self._icons["clear"] = QIcon.fromTheme("clear")
-        self._icons["movie"] = QIcon.fromTheme("movie")
-        self._icons["restore"] = QIcon.fromTheme("restore")
-        self._icons["screenshot"] = QIcon.fromTheme("screenshot")
-        self._icons["visibility_on"] = QIcon.fromTheme("visibility_on")
-        self._icons["visibility_off"] = QIcon.fromTheme("visibility_off")
-        self._icons["folder"] = QIcon.fromTheme("folder")
+        self._icons["help"] = _qicon("help")
+        self._icons["play"] = _qicon("play")
+        self._icons["pause"] = _qicon("pause")
+        self._icons["reset"] = _qicon("reset")
+        self._icons["scale"] = _qicon("scale")
+        self._icons["clear"] = _qicon("clear")
+        self._icons["movie"] = _qicon("movie")
+        self._icons["restore"] = _qicon("restore")
+        self._icons["screenshot"] = _qicon("screenshot")
+        self._icons["visibility_on"] = _qicon("visibility_on")
+        self._icons["visibility_off"] = _qicon("visibility_off")
+        self._icons["folder"] = _qicon("folder")
 
     def _window_clean(self):
         self.figure._plotter = None
@@ -1844,3 +1845,10 @@ def _testing_context(interactive):
     finally:
         pyvista.OFF_SCREEN = orig_offscreen
         renderer.MNE_3D_BACKEND_TESTING = orig_testing
+
+
+def _qicon(name):
+    # Get icon from theme with a file fallback
+    return QIcon.fromTheme(
+        name, QIcon(str(_ICONS_PATH / "light" / "actions" / f"{name}.svg"))
+    )
