@@ -145,19 +145,7 @@ def plot_epochs_image(
         ``overlay_times`` should be ordered to correspond with the
         :class:`~mne.Epochs` object (i.e., ``overlay_times[0]`` corresponds to
         ``epochs[0]``, etc).
-    %(combine)s
-        If callable, the callable must accept one positional input (data of
-        shape ``(n_epochs, n_channels, n_times)``) and return an
-        :class:`array <numpy.ndarray>` of shape ``(n_epochs, n_times)``. For
-        example::
-
-            combine = lambda data: np.median(data, axis=1)
-
-        If ``combine`` is ``None``, channels are combined by computing GFP,
-        unless ``group_by`` is also ``None`` and ``picks`` is a list of
-        specific channels (not channel types), in which case no combining is
-        performed and each channel gets its own figure. See Notes for further
-        details. Defaults to ``None``.
+    %(combine_plot_epochs_image)s
     group_by : None | dict
         Specifies which channels are aggregated into a single figure, with
         aggregation method determined by the ``combine`` parameter. If not
@@ -286,8 +274,8 @@ def plot_epochs_image(
         if len(set(this_ch_type)) > 1:
             types = ", ".join(set(this_ch_type))
             raise ValueError(
-                'Cannot combine sensors of different types; "{}" '
-                "contains types {}.".format(this_group, types)
+                f'Cannot combine sensors of different types; "{this_group}" contains '
+                f"types {types}."
             )
         # now we know they're all the same type...
         group_by[this_group] = dict(
@@ -297,8 +285,8 @@ def plot_epochs_image(
         # are they trying to combine a single channel?
         if len(these_picks) < 2 and combine_given:
             warn(
-                'Only one channel in group "{}"; cannot combine by method '
-                '"{}".'.format(this_group, combine)
+                f'Only one channel in group "{this_group}"; cannot combine by method '
+                f'"{combine}".'
             )
 
     # check for compatible `fig` / `axes`; instantiate figs if needed; add
@@ -437,13 +425,12 @@ def _validate_fig_and_axes(fig, axes, group_by, evoked, colorbar, clear=False):
     n_axes = 1 + int(evoked) + int(colorbar)
     ax_names = ("image", "evoked", "colorbar")
     ax_names = np.array(ax_names)[np.where([True, evoked, colorbar])]
-    prefix = "Since evoked={} and colorbar={}, ".format(evoked, colorbar)
+    prefix = f"Since evoked={evoked} and colorbar={colorbar}, "
 
     # got both fig and axes
     if fig is not None and axes is not None:
         raise ValueError(
-            'At least one of "fig" or "axes" must be None; got '
-            "fig={}, axes={}.".format(fig, axes)
+            f'At least one of "fig" or "axes" must be None; got fig={fig}, axes={axes}.'
         )
 
     # got fig=None and axes=None: make fig(s) and axes
@@ -468,8 +455,7 @@ def _validate_fig_and_axes(fig, axes, group_by, evoked, colorbar, clear=False):
         # `plot_image`, be forgiving of presence/absence of sensor inset axis.
         if len(fig.axes) not in (n_axes, n_axes + 1):
             raise ValueError(
-                '{}"fig" must contain {} axes, got {}.'
-                "".format(prefix, n_axes, len(fig.axes))
+                f'{prefix}"fig" must contain {n_axes} axes, got {len(fig.axes)}.'
             )
         if len(list(group_by)) != 1:
             raise ValueError(
@@ -498,8 +484,7 @@ def _validate_fig_and_axes(fig, axes, group_by, evoked, colorbar, clear=False):
     if isinstance(axes, list):
         if len(axes) != n_axes:
             raise ValueError(
-                '{}"axes" must be length {}, got {}.'
-                "".format(prefix, n_axes, len(axes))
+                f'{prefix}"axes" must be length {n_axes}, got {len(axes)}.'
             )
         # for list of axes to work, must be only one group
         if len(list(group_by)) != 1:
@@ -518,14 +503,14 @@ def _validate_fig_and_axes(fig, axes, group_by, evoked, colorbar, clear=False):
         # group_by dict and the user won't have known what keys we chose.
         if set(axes) != set(group_by):
             raise ValueError(
-                'If "axes" is a dict its keys ({}) must match '
-                'the keys in "group_by" ({}).'.format(list(axes), list(group_by))
+                f'If "axes" is a dict its keys ({list(axes)}) must match the keys in '
+                f'"group_by" ({list(group_by)}).'
             )
         for this_group, this_axes_list in axes.items():
             if len(this_axes_list) != n_axes:
                 raise ValueError(
-                    '{}each value in "axes" must be a list of {} '
-                    "axes, got {}.".format(prefix, n_axes, len(this_axes_list))
+                    f'{prefix}each value in "axes" must be a list of {n_axes} axes, got'
+                    f" {len(this_axes_list)}."
                 )
             # NB: next line assumes all axes in each list are in same figure
             group_by[this_group]["fig"] = this_axes_list[0].get_figure()
@@ -656,10 +641,9 @@ def _plot_epochs_image(
 
     # draw the colorbar
     if colorbar:
-        from matplotlib.pyplot import colorbar as cbar
-
         if "colorbar" in ax:  # axes supplied by user
-            this_colorbar = cbar(im, cax=ax["colorbar"])
+            cax = ax["colorbar"]
+            this_colorbar = cax.figure.colorbar(im, cax=cax)
             this_colorbar.ax.set_ylabel(unit, rotation=270, labelpad=12)
         else:  # we created them
             this_colorbar = fig.colorbar(im, ax=ax_im)
