@@ -855,8 +855,18 @@ def _plot_ica_sources_evoked(evoked, picks, exclude, title, show, ica, labels=No
         lines[-1].set_pickradius(3.0)
 
     ax.set(title=title, xlim=times[[0, -1]], xlabel="Time (ms)", ylabel="(NA)")
-    if len(exclude) > 0:
-        plt.legend(loc="best")
+    leg_lines_labels = list(
+        zip(
+            *[
+                (line, label)
+                for line, label in zip(lines, exclude_labels)
+                if label is not None
+            ]
+        )
+    )
+    if len(leg_lines_labels):
+        leg_lines, leg_labels = leg_lines_labels
+        ax.legend(leg_lines, leg_labels, loc="best")
 
     texts.append(
         ax.text(
