@@ -26,7 +26,7 @@ from mne.utils import _record_warnings, catch_logging
 from mne.viz.ica import _create_properties_layout, plot_ica_properties
 from mne.viz.utils import _fake_click, _fake_keypress
 
-base_dir = Path(__file__).parent.parent.parent / "io" / "tests" / "data"
+base_dir = Path(__file__).parents[2] / "io" / "tests" / "data"
 evoked_fname = base_dir / "test-ave.fif"
 raw_fname = base_dir / "test_raw.fif"
 cov_fname = base_dir / "test-cov.fif"
@@ -157,7 +157,7 @@ def test_plot_ica_properties():
     )
 
     ica = ICA(noise_cov=read_cov(cov_fname), n_components=2, max_iter=1, random_state=0)
-    with pytest.warns(RuntimeWarning, match="projection"):
+    with _record_warnings(), pytest.warns(RuntimeWarning, match="projection"):
         ica.fit(raw)
 
     # test _create_properties_layout
@@ -240,7 +240,7 @@ def test_plot_ica_properties():
     # Test handling of zeros
     ica = ICA(random_state=0, max_iter=1)
     epochs.pick(pick_names)
-    with pytest.warns(UserWarning, match="did not converge"):
+    with _record_warnings(), pytest.warns(UserWarning, match="did not converge"):
         ica.fit(epochs)
     epochs._data[0] = 0
     # Usually UserWarning: Infinite value .* for epo
@@ -254,7 +254,7 @@ def test_plot_ica_properties():
     raw_annot.pick(np.arange(10))
     raw_annot.del_proj()
 
-    with pytest.warns(UserWarning, match="did not converge"):
+    with _record_warnings(), pytest.warns(UserWarning, match="did not converge"):
         ica.fit(raw_annot)
     # drop bad data segments
     fig = ica.plot_properties(raw_annot, picks=[0, 1], **topoargs)
@@ -362,12 +362,15 @@ def test_plot_ica_sources(raw_orig, browser_backend, monkeypatch):
     ica.plot_sources(epochs)
     ica.plot_sources(epochs.average())
     evoked = epochs.average()
+    ica.exclude = [0]
     fig = ica.plot_sources(evoked)
     # Test a click
     ax = fig.get_axes()[0]
     line = ax.lines[0]
     _fake_click(fig, ax, [line.get_xdata()[0], line.get_ydata()[0]], "data")
     _fake_click(fig, ax, [ax.get_xlim()[0], ax.get_ylim()[1]], "data")
+    leg = ax.get_legend()
+    assert len(leg.get_texts()) == len(ica.exclude) == 1
 
     # plot with bad channels excluded
     ica.exclude = [0]
