@@ -30,6 +30,7 @@ from mne.filter import create_filter
 from mne.io import read_raw_fif
 from mne.minimum_norm import read_inverse_operator
 from mne.time_frequency import CrossSpectralDensity
+from mne.utils import _record_warnings
 from mne.viz import (
     plot_bem,
     plot_chpi_snr,
@@ -51,7 +52,7 @@ inv_fname = (
 evoked_fname = data_path / "MEG" / "sample" / "sample_audvis-ave.fif"
 dip_fname = data_path / "MEG" / "sample" / "sample_audvis_trunc_set1.dip"
 chpi_fif_fname = data_path / "SSS" / "test_move_anon_raw.fif"
-base_dir = Path(__file__).parent.parent.parent / "io" / "tests" / "data"
+base_dir = Path(__file__).parents[2] / "io" / "tests" / "data"
 raw_fname = base_dir / "test_raw.fif"
 cov_fname = base_dir / "test-cov.fif"
 event_fname = base_dir / "test-eve.fif"
@@ -214,7 +215,10 @@ def test_plot_events():
     assert fig.axes[0].get_legend() is not None
     with pytest.warns(RuntimeWarning, match="Color was not assigned"):
         plot_events(events, raw.info["sfreq"], raw.first_samp, color=color)
-    with pytest.warns(RuntimeWarning, match=r"vent \d+ missing from event_id"):
+    with (
+        _record_warnings(),
+        pytest.warns(RuntimeWarning, match=r"vent \d+ missing from event_id"),
+    ):
         plot_events(
             events,
             raw.info["sfreq"],
@@ -223,7 +227,7 @@ def test_plot_events():
             color=color,
         )
     multimatch = r"event \d+ missing from event_id|in the color dict but is"
-    with pytest.warns(RuntimeWarning, match=multimatch):
+    with _record_warnings(), pytest.warns(RuntimeWarning, match=multimatch):
         plot_events(
             events,
             raw.info["sfreq"],
@@ -243,7 +247,10 @@ def test_plot_events():
             on_missing="ignore",
         )
     extra_id = {"aud_l": 1, "missing": 111}
-    with pytest.warns(RuntimeWarning, match="from event_id is not present in"):
+    with (
+        _record_warnings(),
+        pytest.warns(RuntimeWarning, match="from event_id is not present in"),
+    ):
         plot_events(
             events,
             raw.info["sfreq"],
@@ -251,7 +258,7 @@ def test_plot_events():
             event_id=extra_id,
             on_missing="warn",
         )
-    with pytest.warns(RuntimeWarning, match="event 2 missing"):
+    with _record_warnings(), pytest.warns(RuntimeWarning, match="event 2 missing"):
         plot_events(
             events,
             raw.info["sfreq"],
