@@ -75,7 +75,11 @@ ALICE, BOB = 0, 1
 [alice_files, bob_files] = fetch_data(subjects=[ALICE, BOB], recording=[1])
 
 raw_train = mne.io.read_raw_edf(
-    alice_files[0], stim_channel="Event marker", infer_types=True, preload=True
+    alice_files[0],
+    stim_channel="Event marker",
+    infer_types=True,
+    preload=True,
+    verbose="error",  # ignore issues with stored filter settings
 )
 annot_train = mne.read_annotations(alice_files[1])
 
@@ -172,7 +176,11 @@ print(epochs_train)
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
 raw_test = mne.io.read_raw_edf(
-    bob_files[0], stim_channel="Event marker", infer_types=True, preload=True
+    bob_files[0],
+    stim_channel="Event marker",
+    infer_types=True,
+    preload=True,
+    verbose="error",
 )
 annot_test = mne.read_annotations(bob_files[1])
 annot_test.crop(annot_test[1]["onset"] - 30 * 60, annot_test[-2]["onset"] + 30 * 60)
@@ -219,6 +227,7 @@ for ax, title, epochs in zip([ax1, ax2], ["Alice", "Bob"], [epochs_train, epochs
             axes=ax,
             show=False,
             average=True,
+            amplitude=False,
             spatial_colors=False,
             picks="data",
             exclude="bads",
@@ -306,7 +315,7 @@ y_pred = pipe.predict(epochs_test)
 y_test = epochs_test.events[:, 2]
 acc = accuracy_score(y_test, y_pred)
 
-print("Accuracy score: {}".format(acc))
+print(f"Accuracy score: {acc}")
 
 ##############################################################################
 # In short, yes. We can predict Bob's sleeping stages based on Alice's data.
