@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _tut-source-alignment:
 
@@ -14,29 +13,29 @@ understanding the different coordinate frames involved in this process.
 Let's start out by loading some data.
 """
 
+# License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 # %%
 
-import numpy as np
 import nibabel as nib
+import numpy as np
 from scipy import linalg
 
 import mne
 from mne.io.constants import FIFF
 
 data_path = mne.datasets.sample.data_path()
-subjects_dir = data_path / 'subjects'
-raw_fname = data_path / 'MEG' / 'sample' / 'sample_audvis_raw.fif'
-trans_fname = (data_path / 'MEG' / 'sample' /
-               'sample_audvis_raw-trans.fif')
+subjects_dir = data_path / "subjects"
+raw_fname = data_path / "MEG" / "sample" / "sample_audvis_raw.fif"
+trans_fname = data_path / "MEG" / "sample" / "sample_audvis_raw-trans.fif"
 raw = mne.io.read_raw_fif(raw_fname)
 trans = mne.read_trans(trans_fname)
-src = mne.read_source_spaces(subjects_dir / 'sample' / 'bem' /
-                             'sample-oct-6-src.fif')
+src = mne.read_source_spaces(subjects_dir / "sample" / "bem" / "sample-oct-6-src.fif")
 
 # Load the T1 file and change the header information to the correct units
-t1w = nib.load(data_path / 'subjects' / 'sample' / 'mri' / 'T1.mgz')
+t1w = nib.load(data_path / "subjects" / "sample" / "mri" / "T1.mgz")
 t1w = nib.Nifti1Image(t1w.dataobj, t1w.affine)
-t1w.header['xyzt_units'] = np.array(10, dtype='uint8')
+t1w.header["xyzt_units"] = np.array(10, dtype="uint8")
 t1_mgh = nib.MGHImage(t1w.dataobj, t1w.affine)
 
 # %%
@@ -69,8 +68,7 @@ t1_mgh = nib.MGHImage(t1w.dataobj, t1w.affine)
 # to their equivalent locations in another. The three main coordinate frames
 # are:
 #
-# * :blue:`"meg"`: the coordinate frame for the physical locations of MEG
-#   sensors
+# * :blue:`"meg"`: the coordinate frame for the physical locations of MEG sensors
 # * :gray:`"mri"`: the coordinate frame for MRI images, and scalp/skull/brain
 #   surfaces derived from the MRI images
 # * :pink:`"head"`: the coordinate frame for digitized sensor locations and
@@ -99,19 +97,33 @@ t1_mgh = nib.MGHImage(t1w.dataobj, t1w.affine)
 # ``coord_frame`` parameter sets which coordinate frame the camera
 # should initially be aligned with. Let's have a look:
 
-fig = mne.viz.plot_alignment(raw.info, trans=trans, subject='sample',
-                             subjects_dir=subjects_dir, surfaces='head-dense',
-                             show_axes=True, dig=True, eeg=[], meg='sensors',
-                             coord_frame='meg', mri_fiducials='estimated')
-mne.viz.set_3d_view(fig, 45, 90, distance=0.6, focalpoint=(0., 0., 0.))
-print('Distance from head origin to MEG origin: %0.1f mm'
-      % (1000 * np.linalg.norm(raw.info['dev_head_t']['trans'][:3, 3])))
-print('Distance from head origin to MRI origin: %0.1f mm'
-      % (1000 * np.linalg.norm(trans['trans'][:3, 3])))
-dists = mne.dig_mri_distances(raw.info, trans, 'sample',
-                              subjects_dir=subjects_dir)
-print('Distance from %s digitized points to head surface: %0.1f mm'
-      % (len(dists), 1000 * np.mean(dists)))
+fig = mne.viz.plot_alignment(
+    raw.info,
+    trans=trans,
+    subject="sample",
+    subjects_dir=subjects_dir,
+    surfaces="head-dense",
+    show_axes=True,
+    dig=True,
+    eeg=[],
+    meg="sensors",
+    coord_frame="meg",
+    mri_fiducials="estimated",
+)
+mne.viz.set_3d_view(fig, 45, 90, distance=0.6, focalpoint=(0.0, 0.0, 0.0))
+print(
+    "Distance from head origin to MEG origin: %0.1f mm"
+    % (1000 * np.linalg.norm(raw.info["dev_head_t"]["trans"][:3, 3]))
+)
+print(
+    "Distance from head origin to MRI origin: %0.1f mm"
+    % (1000 * np.linalg.norm(trans["trans"][:3, 3]))
+)
+dists = mne.dig_mri_distances(raw.info, trans, "sample", subjects_dir=subjects_dir)
+print(
+    f"Distance from {len(dists)} digitized points to head surface: "
+    f"{1000 * np.mean(dists):0.1f} mm"
+)
 
 # %%
 # Coordinate frame definitions
@@ -177,10 +189,17 @@ print('Distance from %s digitized points to head surface: %0.1f mm'
 # Let's try using `~mne.viz.plot_alignment` by making ``trans`` the identity
 # transform. This (incorrectly!) equates the MRI and head coordinate frames.
 
-identity_trans = mne.transforms.Transform('head', 'mri')
-mne.viz.plot_alignment(raw.info, trans=identity_trans, subject='sample',
-                       src=src, subjects_dir=subjects_dir, dig=True,
-                       surfaces=['head-dense', 'white'], coord_frame='meg')
+identity_trans = mne.transforms.Transform("head", "mri")
+mne.viz.plot_alignment(
+    raw.info,
+    trans=identity_trans,
+    subject="sample",
+    src=src,
+    subjects_dir=subjects_dir,
+    dig=True,
+    surfaces=["head-dense", "white"],
+    coord_frame="meg",
+)
 
 # %%
 # A good example
@@ -188,9 +207,16 @@ mne.viz.plot_alignment(raw.info, trans=identity_trans, subject='sample',
 # Here is the same plot, this time with the ``trans`` properly defined
 # (using a precomputed transformation matrix).
 
-mne.viz.plot_alignment(raw.info, trans=trans, subject='sample',
-                       src=src, subjects_dir=subjects_dir, dig=True,
-                       surfaces=['head-dense', 'white'], coord_frame='meg')
+mne.viz.plot_alignment(
+    raw.info,
+    trans=trans,
+    subject="sample",
+    src=src,
+    subjects_dir=subjects_dir,
+    dig=True,
+    surfaces=["head-dense", "white"],
+    coord_frame="meg",
+)
 
 # %%
 # Visualizing the transformations
@@ -208,20 +234,21 @@ mne.viz.plot_alignment(raw.info, trans=trans, subject='sample',
 
 # The head surface is stored in "mri" coordinate frame
 # (origin at center of volume, units=mm)
-seghead_rr, seghead_tri = mne.read_surface(subjects_dir / 'sample' /
-                                           'surf' / 'lh.seghead')
+seghead_rr, seghead_tri = mne.read_surface(
+    subjects_dir / "sample" / "surf" / "lh.seghead"
+)
 
 # To put the scalp in the "head" coordinate frame, we apply the inverse of
 # the precomputed `trans` (which maps head → mri)
-mri_to_head = linalg.inv(trans['trans'])
-scalp_pts_in_head_coord = mne.transforms.apply_trans(
-    mri_to_head, seghead_rr, move=True)
+mri_to_head = linalg.inv(trans["trans"])
+scalp_pts_in_head_coord = mne.transforms.apply_trans(mri_to_head, seghead_rr, move=True)
 
 # To put the scalp in the "meg" coordinate frame, we use the inverse of
 # raw.info['dev_head_t']
-head_to_meg = linalg.inv(raw.info['dev_head_t']['trans'])
+head_to_meg = linalg.inv(raw.info["dev_head_t"]["trans"])
 scalp_pts_in_meg_coord = mne.transforms.apply_trans(
-    head_to_meg, scalp_pts_in_head_coord, move=True)
+    head_to_meg, scalp_pts_in_head_coord, move=True
+)
 
 # The "mri_voxel"→"mri" transform is embedded in the header of the T1 image
 # file. We'll invert it and then apply it to the original `seghead_rr` points.
@@ -229,8 +256,7 @@ scalp_pts_in_meg_coord = mne.transforms.apply_trans(
 # is defined in mm.
 vox_to_mri = t1_mgh.header.get_vox2ras_tkr()
 mri_to_vox = linalg.inv(vox_to_mri)
-scalp_points_in_vox = mne.transforms.apply_trans(
-    mri_to_vox, seghead_rr, move=True)
+scalp_points_in_vox = mne.transforms.apply_trans(mri_to_vox, seghead_rr, move=True)
 
 # %%
 # Now that we've transformed all the points, let's plot them. We'll use the
@@ -239,18 +265,23 @@ scalp_points_in_vox = mne.transforms.apply_trans(
 
 
 def add_head(renderer, points, color, opacity=0.95):
-    renderer.mesh(*points.T, triangles=seghead_tri, color=color,
-                  opacity=opacity)
+    renderer.mesh(*points.T, triangles=seghead_tri, color=color, opacity=opacity)
 
 
 renderer = mne.viz.backends.renderer.create_3d_figure(
-    size=(600, 600), bgcolor='w', scene=False)
-add_head(renderer, seghead_rr, 'gray')
-add_head(renderer, scalp_pts_in_meg_coord, 'blue')
-add_head(renderer, scalp_pts_in_head_coord, 'pink')
-add_head(renderer, scalp_points_in_vox, 'green')
-mne.viz.set_3d_view(figure=renderer.figure, distance=800,
-                    focalpoint=(0., 30., 30.), elevation=105, azimuth=180)
+    size=(600, 600), bgcolor="w", scene=False
+)
+add_head(renderer, seghead_rr, "gray")
+add_head(renderer, scalp_pts_in_meg_coord, "blue")
+add_head(renderer, scalp_pts_in_head_coord, "pink")
+add_head(renderer, scalp_points_in_vox, "green")
+mne.viz.set_3d_view(
+    figure=renderer.figure,
+    distance=800,
+    focalpoint=(0.0, 30.0, 30.0),
+    elevation=105,
+    azimuth=180,
+)
 renderer.show()
 
 # %%
@@ -271,27 +302,36 @@ renderer.show()
 # representative example):
 
 # Get the nasion:
-nasion = [p for p in raw.info['dig'] if
-          p['kind'] == FIFF.FIFFV_POINT_CARDINAL and
-          p['ident'] == FIFF.FIFFV_POINT_NASION][0]
-assert nasion['coord_frame'] == FIFF.FIFFV_COORD_HEAD
-nasion = nasion['r']  # get just the XYZ values
+nasion = [
+    p
+    for p in raw.info["dig"]
+    if p["kind"] == FIFF.FIFFV_POINT_CARDINAL and p["ident"] == FIFF.FIFFV_POINT_NASION
+][0]
+assert nasion["coord_frame"] == FIFF.FIFFV_COORD_HEAD
+nasion = nasion["r"]  # get just the XYZ values
 
 # Transform it from head to MRI space (recall that `trans` is head → mri)
 nasion_mri = mne.transforms.apply_trans(trans, nasion, move=True)
 # Then transform to voxel space, after converting from meters to millimeters
-nasion_vox = mne.transforms.apply_trans(
-    mri_to_vox, nasion_mri * 1e3, move=True)
+nasion_vox = mne.transforms.apply_trans(mri_to_vox, nasion_mri * 1e3, move=True)
 # Plot it to make sure the transforms worked
 renderer = mne.viz.backends.renderer.create_3d_figure(
-    size=(400, 400), bgcolor='w', scene=False)
-add_head(renderer, scalp_points_in_vox, 'green', opacity=1)
-renderer.sphere(center=nasion_vox, color='orange', scale=10)
-mne.viz.set_3d_view(figure=renderer.figure, distance=600.,
-                    focalpoint=(0., 125., 250.), elevation=45, azimuth=180)
+    size=(400, 400), bgcolor="w", scene=False
+)
+add_head(renderer, scalp_points_in_vox, "green", opacity=1)
+renderer.sphere(center=nasion_vox, color="orange", scale=10)
+mne.viz.set_3d_view(
+    figure=renderer.figure,
+    distance=600.0,
+    focalpoint=(0.0, 125.0, 250.0),
+    elevation=45,
+    azimuth=180,
+)
 renderer.show()
 
 # %%
+# .. _creating-trans:
+#
 # Defining the head↔MRI ``trans`` using the GUI
 # ---------------------------------------------
 # You can try creating the head↔MRI transform yourself using
@@ -324,7 +364,7 @@ renderer.show()
 # .. note::
 #     Coregistration can also be automated as shown in :ref:`tut-auto-coreg`.
 
-mne.gui.coregistration(subject='sample', subjects_dir=subjects_dir)
+mne.gui.coregistration(subject="sample", subjects_dir=subjects_dir)
 
 # %%
 # .. _tut-source-alignment-without-mri:
@@ -337,12 +377,19 @@ mne.gui.coregistration(subject='sample', subjects_dir=subjects_dir)
 # to use a :ref:`spherical conductor model <eeg_sphere_model>`. It is
 # passed through ``bem`` parameter.
 
-sphere = mne.make_sphere_model(info=raw.info, r0='auto', head_radius='auto')
-src = mne.setup_volume_source_space(sphere=sphere, pos=10.)
+sphere = mne.make_sphere_model(info=raw.info, r0="auto", head_radius="auto")
+src = mne.setup_volume_source_space(sphere=sphere, pos=10.0)
 mne.viz.plot_alignment(
-    raw.info, trans=trans, eeg='projected', bem=sphere, src=src, dig=True,
-    surfaces=['brain', 'inner_skull', 'outer_skull', 'outer_skin'],
-    coord_frame='meg', show_axes=True)
+    raw.info,
+    trans=trans,
+    eeg="projected",
+    bem=sphere,
+    src=src,
+    dig=True,
+    surfaces=["brain", "inner_skull", "outer_skull", "outer_skin"],
+    coord_frame="meg",
+    show_axes=True,
+)
 
 # %%
 # It is also possible to use :func:`mne.gui.coregistration`
