@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 .. _tut-artifact-sss:
 
@@ -13,19 +12,24 @@ As usual, we'll start by importing the modules we need, loading some
 :ref:`example data <sample-dataset>`, and cropping it to save on memory:
 """
 
+# License: BSD-3-Clause
+# Copyright the MNE-Python contributors.
 # %%
 
 import os
+
 import matplotlib.pyplot as plt
-import seaborn as sns
-import pandas as pd
 import numpy as np
+import pandas as pd
+import seaborn as sns
+
 import mne
 from mne.preprocessing import find_bad_channels_maxwell
 
 sample_data_folder = mne.datasets.sample.data_path()
-sample_data_raw_file = os.path.join(sample_data_folder, 'MEG', 'sample',
-                                    'sample_audvis_raw.fif')
+sample_data_raw_file = os.path.join(
+    sample_data_folder, "MEG", "sample", "sample_audvis_raw.fif"
+)
 raw = mne.io.read_raw_fif(sample_data_raw_file, verbose=False)
 raw.crop(tmax=60)
 
@@ -89,8 +93,8 @@ raw.crop(tmax=60)
 # compensation file (which reduces interference between Elekta's co-located
 # magnetometer and paired gradiometer sensor units).
 
-fine_cal_file = os.path.join(sample_data_folder, 'SSS', 'sss_cal_mgh.dat')
-crosstalk_file = os.path.join(sample_data_folder, 'SSS', 'ct_sparse_mgh.fif')
+fine_cal_file = os.path.join(sample_data_folder, "SSS", "sss_cal_mgh.dat")
+crosstalk_file = os.path.join(sample_data_folder, "SSS", "ct_sparse_mgh.fif")
 
 # %%
 # Before we perform SSS we'll look for bad channels — ``MEG 2443`` is quite
@@ -104,11 +108,15 @@ crosstalk_file = os.path.join(sample_data_folder, 'SSS', 'ct_sparse_mgh.fif')
 #
 # Let's see if we can automatically detect it.
 
-raw.info['bads'] = []
+raw.info["bads"] = []
 raw_check = raw.copy()
 auto_noisy_chs, auto_flat_chs, auto_scores = find_bad_channels_maxwell(
-    raw_check, cross_talk=crosstalk_file, calibration=fine_cal_file,
-    return_scores=True, verbose=True)
+    raw_check,
+    cross_talk=crosstalk_file,
+    calibration=fine_cal_file,
+    return_scores=True,
+    verbose=True,
+)
 print(auto_noisy_chs)  # we should find them!
 print(auto_flat_chs)  # none for this dataset
 
@@ -126,8 +134,8 @@ print(auto_flat_chs)  # none for this dataset
 #
 # Now we can update the list of bad channels in the dataset.
 
-bads = raw.info['bads'] + auto_noisy_chs + auto_flat_chs
-raw.info['bads'] = bads
+bads = raw.info["bads"] + auto_noisy_chs + auto_flat_chs
+raw.info["bads"] = bads
 
 # %%
 # We called `~mne.preprocessing.find_bad_channels_maxwell` with the optional
@@ -139,44 +147,50 @@ raw.info['bads'] = bads
 # the automated detection of *noisy* gradiometer channels.
 
 # Only select the data for gradiometer channels.
-ch_type = 'grad'
-ch_subset = auto_scores['ch_types'] == ch_type
-ch_names = auto_scores['ch_names'][ch_subset]
-scores = auto_scores['scores_noisy'][ch_subset]
-limits = auto_scores['limits_noisy'][ch_subset]
-bins = auto_scores['bins']  # The the windows that were evaluated.
+ch_type = "grad"
+ch_subset = auto_scores["ch_types"] == ch_type
+ch_names = auto_scores["ch_names"][ch_subset]
+scores = auto_scores["scores_noisy"][ch_subset]
+limits = auto_scores["limits_noisy"][ch_subset]
+bins = auto_scores["bins"]  # The the windows that were evaluated.
 # We will label each segment by its start and stop time, with up to 3
 # digits before and 3 digits after the decimal place (1 ms precision).
-bin_labels = [f'{start:3.3f} – {stop:3.3f}'
-              for start, stop in bins]
+bin_labels = [f"{start:3.3f} – {stop:3.3f}" for start, stop in bins]
 
 # We store the data in a Pandas DataFrame. The seaborn heatmap function
 # we will call below will then be able to automatically assign the correct
 # labels to all axes.
-data_to_plot = pd.DataFrame(data=scores,
-                            columns=pd.Index(bin_labels, name='Time (s)'),
-                            index=pd.Index(ch_names, name='Channel'))
+data_to_plot = pd.DataFrame(
+    data=scores,
+    columns=pd.Index(bin_labels, name="Time (s)"),
+    index=pd.Index(ch_names, name="Channel"),
+)
 
 # First, plot the "raw" scores.
-fig, ax = plt.subplots(1, 2, figsize=(12, 8))
-fig.suptitle(f'Automated noisy channel detection: {ch_type}',
-             fontsize=16, fontweight='bold')
-sns.heatmap(data=data_to_plot, cmap='Reds', cbar_kws=dict(label='Score'),
-            ax=ax[0])
-[ax[0].axvline(x, ls='dashed', lw=0.25, dashes=(25, 15), color='gray')
-    for x in range(1, len(bins))]
-ax[0].set_title('All Scores', fontweight='bold')
+fig, ax = plt.subplots(1, 2, figsize=(12, 8), layout="constrained")
+fig.suptitle(
+    f"Automated noisy channel detection: {ch_type}", fontsize=16, fontweight="bold"
+)
+sns.heatmap(data=data_to_plot, cmap="Reds", cbar_kws=dict(label="Score"), ax=ax[0])
+[
+    ax[0].axvline(x, ls="dashed", lw=0.25, dashes=(25, 15), color="gray")
+    for x in range(1, len(bins))
+]
+ax[0].set_title("All Scores", fontweight="bold")
 
 # Now, adjust the color range to highlight segments that exceeded the limit.
-sns.heatmap(data=data_to_plot,
-            vmin=np.nanmin(limits),  # bads in input data have NaN limits
-            cmap='Reds', cbar_kws=dict(label='Score'), ax=ax[1])
-[ax[1].axvline(x, ls='dashed', lw=0.25, dashes=(25, 15), color='gray')
-    for x in range(1, len(bins))]
-ax[1].set_title('Scores > Limit', fontweight='bold')
-
-# The figure title should not overlap with the subplots.
-fig.tight_layout(rect=[0, 0.03, 1, 0.95])
+sns.heatmap(
+    data=data_to_plot,
+    vmin=np.nanmin(limits),  # bads in input data have NaN limits
+    cmap="Reds",
+    cbar_kws=dict(label="Score"),
+    ax=ax[1],
+)
+[
+    ax[1].axvline(x, ls="dashed", lw=0.25, dashes=(25, 15), color="gray")
+    for x in range(1, len(bins))
+]
+ax[1].set_title("Scores > Limit", fontweight="bold")
 
 # %%
 #
@@ -211,7 +225,7 @@ fig.tight_layout(rect=[0, 0.03, 1, 0.95])
 # the channel as bad. So it can still be useful to manually inspect and mark
 # bad channels. The channel in question is ``MEG 2313``. Let's mark it as bad:
 
-raw.info['bads'] += ['MEG 2313']  # from manual inspection
+raw.info["bads"] += ["MEG 2313"]  # from manual inspection
 
 # %%
 # After that, performing SSS and Maxwell filtering is done with a
@@ -219,14 +233,15 @@ raw.info['bads'] += ['MEG 2313']  # from manual inspection
 # and fine calibration filenames provided (if available):
 
 raw_sss = mne.preprocessing.maxwell_filter(
-    raw, cross_talk=crosstalk_file, calibration=fine_cal_file, verbose=True)
+    raw, cross_talk=crosstalk_file, calibration=fine_cal_file, verbose=True
+)
 
 # %%
 # To see the effect, we can plot the data before and after SSS / Maxwell
 # filtering.
 
-raw.pick(['meg']).plot(duration=2, butterfly=True)
-raw_sss.pick(['meg']).plot(duration=2, butterfly=True)
+raw.pick(["meg"]).plot(duration=2, butterfly=True)
+raw_sss.pick(["meg"]).plot(duration=2, butterfly=True)
 
 # %%
 # Notice that channels marked as "bad" have been effectively repaired by SSS,
@@ -300,26 +315,28 @@ raw_sss.pick(['meg']).plot(duration=2, butterfly=True)
 # want to doublecheck, you can use :func:`mne.chpi.get_active_chpi` (currently
 # only implemented for neuromag systems).
 
-chpi_fif_file = os.path.join(mne.datasets.testing.data_path(), 'SSS',
-                             'test_move_anon_raw.fif')
-raw = mne.io.read_raw_fif(chpi_fif_file, allow_maxshield='yes')
+chpi_fif_file = os.path.join(
+    mne.datasets.testing.data_path(), "SSS", "test_move_anon_raw.fif"
+)
+raw = mne.io.read_raw_fif(chpi_fif_file, allow_maxshield="yes")
 
 # time-resolved information on active HPI coils
 # if all hpi were inactive n_active is a zero-array
 n_active = mne.chpi.get_active_chpi(raw)
-print(f'Average number of coils active during recording: {n_active.mean()}')
+print(f"Average number of coils active during recording: {n_active.mean()}")
 
 # %%
 # Head position data can be computed using
 # :func:`mne.chpi.compute_chpi_locs` and :func:`mne.chpi.compute_head_pos`,
-# or loaded with the:func:`mne.chpi.read_head_pos` function. The
+# or loaded with the :func:`mne.chpi.read_head_pos` function. The
 # :ref:`example data <sample-dataset>` doesn't include cHPI, so here we'll
 # load a :file:`.pos` file used for testing, just to demonstrate:
 
-head_pos_file = os.path.join(mne.datasets.testing.data_path(), 'SSS',
-                             'test_move_anon_raw.pos')
+head_pos_file = os.path.join(
+    mne.datasets.testing.data_path(), "SSS", "test_move_anon_raw.pos"
+)
 head_pos = mne.chpi.read_head_pos(head_pos_file)
-mne.viz.plot_head_positions(head_pos, mode='traces')
+mne.viz.plot_head_positions(head_pos, mode="traces")
 
 # %%
 # The cHPI data file could also be passed as the ``head_pos`` parameter of
