@@ -142,10 +142,10 @@ time_secs = raw.times
 ch_names = raw.ch_names
 n_chan = len(ch_names)  # note: there is no raw.n_channels attribute
 print(
-    "the (cropped) sample data object has {} time samples and {} channels."
-    "".format(n_time_samps, n_chan)
+    f"the (cropped) sample data object has {n_time_samps} time samples and "
+    f"{n_chan} channels."
 )
-print("The last time sample is at {} seconds.".format(time_secs[-1]))
+print(f"The last time sample is at {time_secs[-1]} seconds.")
 print("The first few channel names are {}.".format(", ".join(ch_names[:3])))
 print()  # insert a blank line in the output
 
@@ -291,9 +291,12 @@ print(raw.ch_names[-3:])
 # inaccurate, you can change the type of any channel with the
 # :meth:`~mne.io.Raw.set_channel_types` method. The method takes a
 # :class:`dictionary <dict>` mapping channel names to types; allowed types are
-# ``ecg, eeg, emg, eog, exci, ias, misc, resp, seeg, dbs, stim, syst, ecog,
-# hbo, hbr``. A common use case for changing channel type is when using frontal
-# EEG electrodes as makeshift EOG channels:
+# ``bio, chpi, csd, dbs, dipole, ecg, ecog, eeg, emg, eog, exci, eyegaze,
+# fnirs_cw_amplitude, fnirs_fd_ac_amplitude, fnirs_fd_phase, fnirs_od, gof,
+# gsr, hbo, hbr, ias, misc, pupil, ref_meg, resp, seeg, stim, syst,
+# temperature`` (see :term:`sensor types` for more information about them).
+# A common use case for changing channel type is when using frontal EEG
+# electrodes as makeshift EOG channels:
 
 raw.set_channel_types({"EEG_001": "eog"})
 print(raw.copy().pick(picks="eog").ch_names)
