@@ -8,9 +8,9 @@
 The Spectrum and EpochsSpectrum classes: frequency-domain data
 ==============================================================
 
-This tutorial shows how to create and visualize frequency-domain
-representations of your data, starting from continuous :class:`~mne.io.Raw`,
-discontinuous :class:`~mne.Epochs`, or averaged :class:`~mne.Evoked` data.
+This tutorial shows how to create and visualize frequency-domain representations of your
+data, starting from continuous :class:`~mne.io.Raw`, discontinuous :class:`~mne.Epochs`,
+or averaged :class:`~mne.Evoked` data.
 
 As usual we'll start by importing the modules we need, and loading our
 :ref:`sample dataset <sample-dataset>`:
@@ -122,7 +122,7 @@ epo_spectrum["visual"]
 # (interpolated scalp topography of power, in specific frequency bands). A few
 # plot options are demonstrated below; see the docstrings for full details.
 
-evk_spectrum.plot(picks="data", exclude="bads")
+evk_spectrum.plot(picks="data", exclude="bads", amplitude=False)
 evk_spectrum.plot_topo(color="k", fig_facecolor="w", axis_facecolor="w")
 
 # %%
