@@ -84,14 +84,12 @@ raw.set_eeg_reference("average", projection=False, verbose=False)
 raw.filter(l_freq=0.1, h_freq=None, fir_design="firwin", verbose=False)
 
 # Construct epochs
-event_id = {"12hz": 255, "15hz": 155}
-events, _ = mne.events_from_annotations(raw, verbose=False)
+raw.annotations.rename({"Stimulus/S255": "12hz", "Stimulus/S155": "15hz"})
 tmin, tmax = -1.0, 20.0  # in s
 baseline = None
 epochs = mne.Epochs(
     raw,
-    events=events,
-    event_id=[event_id["12hz"], event_id["15hz"]],
+    event_id=["12hz", "15hz"],
     tmin=tmin,
     tmax=tmax,
     baseline=baseline,
@@ -356,8 +354,8 @@ i_bin_45hz = np.argmin(abs(freqs - 45))
 # Get indices for the different trial types
 # ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
-i_trial_12hz = np.where(epochs.events[:, 2] == event_id["12hz"])[0]
-i_trial_15hz = np.where(epochs.events[:, 2] == event_id["15hz"])[0]
+i_trial_12hz = np.where(epochs.annotations.description == "12hz")[0]
+i_trial_15hz = np.where(epochs.annotations.description == "15hz")[0]
 
 # %%
 # Get indices of EEG channels forming the ROI
@@ -424,13 +422,13 @@ fig, ax = plt.subplots(1)
 mne.viz.plot_topomap(snrs_12hz_chaverage, epochs.info, vlim=(1, None), axes=ax)
 
 print("sub 2, 12 Hz trials, SNR at 12 Hz")
-print("average SNR (all channels): %f" % snrs_12hz_chaverage.mean())
-print("average SNR (occipital ROI): %f" % snrs_target.mean())
+print(f"average SNR (all channels): {snrs_12hz_chaverage.mean()}")
+print(f"average SNR (occipital ROI): {snrs_target.mean()}")
 
 tstat_roi_vs_scalp = ttest_rel(snrs_target.mean(axis=1), snrs_12hz.mean(axis=1))
 print(
-    "12 Hz SNR in occipital ROI is significantly larger than 12 Hz SNR over "
-    "all channels: t = %.3f, p = %f" % tstat_roi_vs_scalp
+    "12 Hz SNR in occipital ROI is significantly larger than 12 Hz SNR over all "
+    f"channels: t = {tstat_roi_vs_scalp[0]:.3f}, p = {tstat_roi_vs_scalp[1]}"
 )
 
 ##############################################################################
@@ -522,24 +520,24 @@ tstat_12hz_trial_stim = ttest_rel(
     res["stim_12hz_snrs_12hz"], res["stim_12hz_snrs_15hz"]
 )
 print(
-    "12 Hz Trials: 12 Hz SNR is significantly higher than 15 Hz SNR"
-    ": t = %.3f, p = %f" % tstat_12hz_trial_stim
+    "12 Hz Trials: 12 Hz SNR is significantly higher than 15 Hz SNR: t = "
+    f"{tstat_12hz_trial_stim[0]:.3f}, p = {tstat_12hz_trial_stim[1]}"
 )
 
 tstat_12hz_trial_1st_harmonic = ttest_rel(
     res["stim_12hz_snrs_24hz"], res["stim_12hz_snrs_30hz"]
 )
 print(
-    "12 Hz Trials: 24 Hz SNR is significantly higher than 30 Hz SNR"
-    ": t = %.3f, p = %f" % tstat_12hz_trial_1st_harmonic
+    "12 Hz Trials: 24 Hz SNR is significantly higher than 30 Hz SNR: t = "
+    f"{tstat_12hz_trial_1st_harmonic[0]:.3f}, p = {tstat_12hz_trial_1st_harmonic[1]}"
 )
 
 tstat_12hz_trial_2nd_harmonic = ttest_rel(
     res["stim_12hz_snrs_36hz"], res["stim_12hz_snrs_45hz"]
 )
 print(
-    "12 Hz Trials: 36 Hz SNR is significantly higher than 45 Hz SNR"
-    ": t = %.3f, p = %f" % tstat_12hz_trial_2nd_harmonic
+    "12 Hz Trials: 36 Hz SNR is significantly higher than 45 Hz SNR: t = "
+    f"{tstat_12hz_trial_2nd_harmonic[0]:.3f}, p = {tstat_12hz_trial_2nd_harmonic[1]}"
 )
 
 print()
@@ -547,24 +545,24 @@ tstat_15hz_trial_stim = ttest_rel(
     res["stim_15hz_snrs_12hz"], res["stim_15hz_snrs_15hz"]
 )
 print(
-    "15 Hz trials: 12 Hz SNR is significantly lower than 15 Hz SNR"
-    ": t = %.3f, p = %f" % tstat_15hz_trial_stim
+    "15 Hz trials: 12 Hz SNR is significantly lower than 15 Hz SNR: t = "
+    f"{tstat_15hz_trial_stim[0]:.3f}, p = {tstat_15hz_trial_stim[1]}"
 )
 
 tstat_15hz_trial_1st_harmonic = ttest_rel(
     res["stim_15hz_snrs_24hz"], res["stim_15hz_snrs_30hz"]
 )
 print(
-    "15 Hz trials: 24 Hz SNR is significantly lower than 30 Hz SNR"
-    ": t = %.3f, p = %f" % tstat_15hz_trial_1st_harmonic
+    "15 Hz trials: 24 Hz SNR is significantly lower than 30 Hz SNR: t = "
+    f"{tstat_15hz_trial_1st_harmonic[0]:.3f}, p = {tstat_15hz_trial_1st_harmonic[1]}"
 )
 
 tstat_15hz_trial_2nd_harmonic = ttest_rel(
     res["stim_15hz_snrs_36hz"], res["stim_15hz_snrs_45hz"]
 )
 print(
-    "15 Hz trials: 36 Hz SNR is significantly lower than 45 Hz SNR"
-    ": t = %.3f, p = %f" % tstat_15hz_trial_2nd_harmonic
+    "15 Hz trials: 36 Hz SNR is significantly lower than 45 Hz SNR: t = "
+    f"{tstat_15hz_trial_2nd_harmonic[0]:.3f}, p = {tstat_15hz_trial_2nd_harmonic[1]}"
 )
 
 ##############################################################################
@@ -604,7 +602,7 @@ window_lengths = [i for i in range(2, 21, 2)]
 window_snrs = [[]] * len(window_lengths)
 for i_win, win in enumerate(window_lengths):
     # compute spectrogram
-    this_spectrum = epochs[str(event_id["12hz"])].compute_psd(
+    this_spectrum = epochs["12hz"].compute_psd(
         "welch",
         n_fft=int(sfreq * win),
         n_overlap=0,
@@ -688,7 +686,7 @@ window_snrs = [[]] * len(window_starts)
 
 for i_win, win in enumerate(window_starts):
     # compute spectrogram
-    this_spectrum = epochs[str(event_id["12hz"])].compute_psd(
+    this_spectrum = epochs["12hz"].compute_psd(
         "welch",
         n_fft=int(sfreq * window_length) - 1,
         n_overlap=0,
